/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_FL3NGR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_FL3NGR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_FL3NGR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FL3NGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FL3NGR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_FL3NGR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FL3NGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FL3NGR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_FL3NGR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_FL3NGR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_FL3NGR::Heavy_WSTD_FL3NGR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_L9LOYhNx);
  numBytes += sLine_init(&sLine_VO4x8yeb);
  numBytes += sLine_init(&sLine_3mvtgJO8);
  numBytes += sLine_init(&sLine_lVwKnrMZ);
  numBytes += sLine_init(&sLine_wJeue3mA);
  numBytes += sBiquad_init(&sBiquad_s_eLcuktGn);
  numBytes += sLine_init(&sLine_biSOmqb0);
  numBytes += sLine_init(&sLine_kCX9mIRq);
  numBytes += sLine_init(&sLine_TPv0Li4m);
  numBytes += sLine_init(&sLine_9rPNVi0c);
  numBytes += sBiquad_init(&sBiquad_s_92xXZZqf);
  numBytes += sLine_init(&sLine_CULt5gCq);
  numBytes += sLine_init(&sLine_Nh6qBen3);
  numBytes += sLine_init(&sLine_8wMMkJl4);
  numBytes += sLine_init(&sLine_vsvWMAPR);
  numBytes += sLine_init(&sLine_MvQJcrV1);
  numBytes += sBiquad_init(&sBiquad_s_NM2tn7WU);
  numBytes += sLine_init(&sLine_oMMpsgRW);
  numBytes += sLine_init(&sLine_nHA1MKoK);
  numBytes += sLine_init(&sLine_WS07jkZu);
  numBytes += sLine_init(&sLine_AFY8em8B);
  numBytes += sLine_init(&sLine_kIPvVVrh);
  numBytes += sBiquad_init(&sBiquad_s_36UDCi5k);
  numBytes += sLine_init(&sLine_ZYFwohQJ);
  numBytes += sLine_init(&sLine_k4k9iJ3E);
  numBytes += sLine_init(&sLine_UqCvs45e);
  numBytes += sLine_init(&sLine_8ezbnnkl);
  numBytes += sBiquad_init(&sBiquad_s_LXfmEd6w);
  numBytes += sLine_init(&sLine_uxgUaP1E);
  numBytes += sLine_init(&sLine_geS9R11w);
  numBytes += sLine_init(&sLine_rcW4s83b);
  numBytes += sLine_init(&sLine_3txu3z0o);
  numBytes += sLine_init(&sLine_siPf779k);
  numBytes += sBiquad_init(&sBiquad_s_Xe8Vh5CP);
  numBytes += sLine_init(&sLine_ZQ1yPd0l);
  numBytes += sPhasor_k_init(&sPhasor_t5PLyRQh, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_ZB03CxYH);
  numBytes += sRPole_init(&sRPole_PEHzEfCH);
  numBytes += sRPole_init(&sRPole_3JHzQjyP);
  numBytes += sTabhead_init(&sTabhead_rtI2IlF8, &hTable_g9CiPUI0);
  numBytes += sTabread_init(&sTabread_0a1CQn1S, &hTable_g9CiPUI0, false);
  numBytes += sTabread_init(&sTabread_KDX8J2NZ, &hTable_g9CiPUI0, false);
  numBytes += sLine_init(&sLine_qLZT2gtM);
  numBytes += sTabhead_init(&sTabhead_3nm4AZoy, &hTable_ugBSGtxz);
  numBytes += sTabread_init(&sTabread_1z7pPDaq, &hTable_ugBSGtxz, false);
  numBytes += sTabread_init(&sTabread_Z0Dk50Er, &hTable_ugBSGtxz, false);
  numBytes += sLine_init(&sLine_p3YWPFTc);
  numBytes += sTabwrite_init(&sTabwrite_1ZvKaPRr, &hTable_ugBSGtxz);
  numBytes += sTabwrite_init(&sTabwrite_QU0jAle7, &hTable_g9CiPUI0);
  numBytes += sLine_init(&sLine_mZpfgJwN);
  numBytes += sPhasor_k_init(&sPhasor_MFfnDIXH, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_UzMx3SW2);
  numBytes += sRPole_init(&sRPole_g1vysm1N);
  numBytes += sRPole_init(&sRPole_gW2qYKse);
  numBytes += sTabhead_init(&sTabhead_sIxz4ZqX, &hTable_OclzoPJK);
  numBytes += sTabread_init(&sTabread_zmc7VCxE, &hTable_OclzoPJK, false);
  numBytes += sTabread_init(&sTabread_SHtd5177, &hTable_OclzoPJK, false);
  numBytes += sLine_init(&sLine_nzhXFS5d);
  numBytes += sTabhead_init(&sTabhead_FVTADis8, &hTable_6z2NtUSM);
  numBytes += sTabread_init(&sTabread_WbarWyuN, &hTable_6z2NtUSM, false);
  numBytes += sTabread_init(&sTabread_FjRoJ2ml, &hTable_6z2NtUSM, false);
  numBytes += sLine_init(&sLine_oL7M6Xm2);
  numBytes += sTabwrite_init(&sTabwrite_7S872WnF, &hTable_6z2NtUSM);
  numBytes += sTabwrite_init(&sTabwrite_BpMsIEFE, &hTable_OclzoPJK);
  numBytes += sLine_init(&sLine_vTZQqP6D);
  numBytes += sPhasor_k_init(&sPhasor_xR2zUXJ0, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_du0DsJXK);
  numBytes += sRPole_init(&sRPole_hbb4vwH1);
  numBytes += sRPole_init(&sRPole_0bHYdgYU);
  numBytes += sTabhead_init(&sTabhead_Jwd0p7Mw, &hTable_GNIhoEIA);
  numBytes += sTabread_init(&sTabread_tmd7bIei, &hTable_GNIhoEIA, false);
  numBytes += sTabread_init(&sTabread_F6oku9W2, &hTable_GNIhoEIA, false);
  numBytes += sLine_init(&sLine_ywzdwClY);
  numBytes += sTabhead_init(&sTabhead_1PTo7N8K, &hTable_PJYILIsE);
  numBytes += sTabread_init(&sTabread_nMyeTIE1, &hTable_PJYILIsE, false);
  numBytes += sTabread_init(&sTabread_dlHaok7b, &hTable_PJYILIsE, false);
  numBytes += sLine_init(&sLine_KVnkE6T3);
  numBytes += sTabwrite_init(&sTabwrite_KDBXC4TL, &hTable_PJYILIsE);
  numBytes += sTabwrite_init(&sTabwrite_dqPiu7M0, &hTable_GNIhoEIA);
  numBytes += cVar_init_f(&cVar_kyIz4kXB, 0.0f);
  numBytes += cVar_init_f(&cVar_bV0ALgs9, 0.0f);
  numBytes += cVar_init_f(&cVar_DFir1q6w, 0.0f);
  numBytes += cVar_init_f(&cVar_27tAIEXJ, 0.0f);
  numBytes += cSlice_init(&cSlice_M4xV690U, 1, -1);
  numBytes += cVar_init_f(&cVar_9jXwFnbb, 1337.0f);
  numBytes += cVar_init_f(&cVar_xtgz3lw3, 0.0f);
  numBytes += cIf_init(&cIf_Qra67SBu, false);
  numBytes += cIf_init(&cIf_fLAvcqQx, false);
  numBytes += cBinop_init(&cBinop_rRpDcj6C, 0.0f); // __pow
  numBytes += cIf_init(&cIf_381XIGlW, false);
  numBytes += cBinop_init(&cBinop_oksfO5pu, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_nhorBcs6, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_d9O6PL8B, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_PyVGAy3t, 0.0f);
  numBytes += cIf_init(&cIf_ObcdliBW, false);
  numBytes += cIf_init(&cIf_K0QhnQkf, false);
  numBytes += cBinop_init(&cBinop_hagsf17Z, 0.0f); // __pow
  numBytes += cIf_init(&cIf_OxTbvMoF, false);
  numBytes += cBinop_init(&cBinop_7dsET4ak, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_R6XhYeIF, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_SfQrZ12p, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_8LVHlTis, 0.0f);
  numBytes += cIf_init(&cIf_MVTiJahZ, false);
  numBytes += cIf_init(&cIf_Shvo7DDa, false);
  numBytes += cBinop_init(&cBinop_U8GJWqtA, 0.0f); // __pow
  numBytes += cIf_init(&cIf_a17vga5e, false);
  numBytes += cBinop_init(&cBinop_mYYlOmys, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_eFQBZzd9, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_tHDQrMuE, -15.0f); // __eq
  numBytes += cIf_init(&cIf_k1OEIxfI, false);
  numBytes += cSlice_init(&cSlice_eoKsuCuD, 1, -1);
  numBytes += cVar_init_f(&cVar_E4sIX6uI, 0.0f);
  numBytes += cSlice_init(&cSlice_h5a1Jp1v, 1, -1);
  numBytes += cVar_init_f(&cVar_YPbLKPzE, 0.0f);
  numBytes += cSlice_init(&cSlice_1R05djxm, 1, -1);
  numBytes += cVar_init_f(&cVar_IgyCuGKC, 0.0f);
  numBytes += cSlice_init(&cSlice_wVFvirho, 1, -1);
  numBytes += cVar_init_f(&cVar_a9yTzArx, 0.313f);
  numBytes += cBinop_init(&cBinop_sWE6o7lk, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_obv1cpWu, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_lQDm0a6o, 0.0f);
  numBytes += cVar_init_f(&cVar_vJzLuHij, 1337.0f);
  numBytes += cVar_init_f(&cVar_e1gG4YNn, 0.3f);
  numBytes += cBinop_init(&cBinop_40imlosr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vtpopmVP, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_FLnoLTs9, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_hQCaSHMn, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_E12duryJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XgTvaRxg, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XkKblgGM, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_iLu6U0Z5, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_ac0YlViY, 0.0f);
  numBytes += cVar_init_f(&cVar_pg8KPQfj, 1337.0f);
  numBytes += cVar_init_f(&cVar_KtM8pUGB, 0.313f);
  numBytes += cBinop_init(&cBinop_ZksDLrDq, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_oDKf9Q5z, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_NNn4fcxp, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_BAQE0v5T, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_k8AAdmHG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_BVqsxjLw, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_5r43D77g, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_1U0Mssol, 0.0f);
  numBytes += cVar_init_f(&cVar_MaQQSZWn, 1037.0f);
  numBytes += cVar_init_f(&cVar_BOJSm5ik, 0.4f);
  numBytes += cBinop_init(&cBinop_PmjG30eZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_MpQfg6MK, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_NzS2jIwL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_EtF3Jho8, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ELNVIXTx, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_HgL7xnTf, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_qCqo5Gvc, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cAzZHvSy, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_q6QfuSRd, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_Fmj1G8qm, 1, -1);
  numBytes += cVar_init_f(&cVar_GzeUIWbB, 1337.0f);
  numBytes += cVar_init_f(&cVar_WtRAwYBO, 0.0f);
  numBytes += cIf_init(&cIf_nFLhojuB, false);
  numBytes += cIf_init(&cIf_cOMqDXUF, false);
  numBytes += cBinop_init(&cBinop_1nM3FD1h, 0.0f); // __pow
  numBytes += cIf_init(&cIf_4w4UkMci, false);
  numBytes += cBinop_init(&cBinop_Ebcgblkq, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_5l8dcbte, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_S6ae0NqB, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_UQfqt1ez, 0.0f);
  numBytes += cIf_init(&cIf_vGZ0IMbu, false);
  numBytes += cIf_init(&cIf_ITbinu90, false);
  numBytes += cBinop_init(&cBinop_8Meatvby, 0.0f); // __pow
  numBytes += cIf_init(&cIf_96FoSolo, false);
  numBytes += cBinop_init(&cBinop_i0MPQoPF, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_3ADkGj1n, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_AWu3ugC2, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_KQnU6oAw, 0.0f);
  numBytes += cIf_init(&cIf_pqMge7z9, false);
  numBytes += cIf_init(&cIf_HBRG1S6s, false);
  numBytes += cBinop_init(&cBinop_KbsL4hZy, 0.0f); // __pow
  numBytes += cIf_init(&cIf_eRH0UaJQ, false);
  numBytes += cBinop_init(&cBinop_Y68vpTt5, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_HE77MH3R, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_kn8ShmFm, -15.0f); // __eq
  numBytes += cIf_init(&cIf_rvXf6ZS5, false);
  numBytes += cSlice_init(&cSlice_vS4GJ3eU, 1, -1);
  numBytes += cVar_init_f(&cVar_oiHyJx6A, 0.0f);
  numBytes += cSlice_init(&cSlice_msgjMxms, 1, -1);
  numBytes += cVar_init_f(&cVar_gYSnhorf, 0.0f);
  numBytes += cSlice_init(&cSlice_gXpUHbRw, 1, -1);
  numBytes += cVar_init_f(&cVar_UlbVWQvj, 0.0f);
  numBytes += cSlice_init(&cSlice_hnSHIGIk, 1, -1);
  numBytes += cVar_init_f(&cVar_vkD0wuso, 0.313f);
  numBytes += cBinop_init(&cBinop_qVIfFBQT, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_jzUAkt0C, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_ya3EBSnd, 0.0f);
  numBytes += cVar_init_f(&cVar_njdIrW7j, 1337.0f);
  numBytes += cVar_init_f(&cVar_3At2mtSC, 0.3f);
  numBytes += cBinop_init(&cBinop_Z8a9pmxQ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_teZHzp1l, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_sbnt4hoR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_usyukM1a, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_iqMkFVfr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_QgpSYnW4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XC6rkoSz, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_QB3Uqh9M, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_5v1nkOTQ, 0.0f);
  numBytes += cVar_init_f(&cVar_jdKsWt58, 1337.0f);
  numBytes += cVar_init_f(&cVar_PLhntHKt, 0.313f);
  numBytes += cBinop_init(&cBinop_EvuojrHh, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_mFRVKTdQ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_r93F0qgQ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_HokiqOyQ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ypBW4VAx, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_INo2Ydgt, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_Qfzsyu7e, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_KGm2VA63, 0.0f);
  numBytes += cVar_init_f(&cVar_uzkaHJOp, 1037.0f);
  numBytes += cVar_init_f(&cVar_AXUsaVsv, 0.4f);
  numBytes += cBinop_init(&cBinop_PovzMPFU, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_2yQtAL5P, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_5dFVdY61, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_d2nUouNT, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_2JPJfJKR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_5Gw5yqSH, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_asFtP1wS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eq5j0DXF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_B8hZEEEN, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_W3BKb8uz, 5705.6f);
  numBytes += cVar_init_f(&cVar_u4qVfOwf, 313.3f);
  numBytes += cBinop_init(&cBinop_I5hCXIwy, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_Je7sTOEi, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_Tst1gHC9, 0.0f); // __div
  numBytes += cVar_init_f(&cVar_3H45LZgG, 0.0f);
  numBytes += cVar_init_f(&cVar_OceFT3pO, 0.0f);
  numBytes += cVar_init_f(&cVar_SEU4j2ap, 0.0f);
  numBytes += cVar_init_f(&cVar_Kz5hAdSJ, 0.0f);
  numBytes += cVar_init_f(&cVar_ITs6T9pu, 0.0f);
  numBytes += cVar_init_f(&cVar_Hk2G3AlN, 0.0f);
  numBytes += cVar_init_f(&cVar_TVB2okV1, 0.0f);
  numBytes += cVar_init_f(&cVar_4VgTOIDL, 0.0f);
  numBytes += cVar_init_f(&cVar_WW28TwDG, 0.0f);
  numBytes += cVar_init_f(&cVar_3O0KiQT8, 0.0f);
  numBytes += cVar_init_f(&cVar_vj3eaO0U, 0.0f);
  numBytes += cVar_init_f(&cVar_KyAPJ2t3, 0.0f);
  numBytes += cVar_init_s(&cVar_6mo1Axmw, "del-1348-flanger-l");
  numBytes += sVarf_init(&sVarf_W1bpn2ag, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oRdFBhFK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OSiwjeOb, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_bvTC7SML, "del-1348-flanger-r");
  numBytes += sVarf_init(&sVarf_emXxiq7h, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_PTHoH5GW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_diFkhrzT, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_DseSYvFC, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Ij4YxkeB, 0.0f);
  numBytes += hTable_init(&hTable_ugBSGtxz, 256);
  numBytes += cDelay_init(this, &cDelay_UCp5jRQp, 0.0f);
  numBytes += cDelay_init(this, &cDelay_cczfQvs6, 0.0f);
  numBytes += hTable_init(&hTable_g9CiPUI0, 256);
  numBytes += cVar_init_f(&cVar_ohB1HmBR, 14.0f);
  numBytes += cBinop_init(&cBinop_QBWRwCJO, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_DEAaBuJe, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_DonbzVrf, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_KSRqOgiI, 14.0f);
  numBytes += cBinop_init(&cBinop_fX0iivpn, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_rGOWihpy, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cCeOUQrS, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_exRFuGf1, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_P8BxNnOj, 1, -1);
  numBytes += cVar_init_f(&cVar_iKqe2wg8, 0.2f);
  numBytes += cSlice_init(&cSlice_w5Ry0Ew0, 1, -1);
  numBytes += cVar_init_f(&cVar_MWqu7Zec, 0.0f);
  numBytes += cSlice_init(&cSlice_b4fYygAl, 1, -1);
  numBytes += cVar_init_f(&cVar_p5X2YWeN, 2.0f);
  numBytes += cSlice_init(&cSlice_FEM2Hz2r, 1, -1);
  numBytes += cVar_init_f(&cVar_Hi7zlKLa, 0.5f);
  numBytes += cVar_init_s(&cVar_bxWMrwdF, "del-1397-flanger-l");
  numBytes += sVarf_init(&sVarf_JMEunFMf, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TfwLsmb1, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9AYK4ryW, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_Td0UU3e0, "del-1397-flanger-r");
  numBytes += sVarf_init(&sVarf_6KJEPjWl, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_yBhnDiMj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HZ1FVPwN, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_Ad5wauPi, 0.0f);
  numBytes += cDelay_init(this, &cDelay_OF5SqfHp, 0.0f);
  numBytes += hTable_init(&hTable_6z2NtUSM, 256);
  numBytes += cDelay_init(this, &cDelay_IZCbdcmS, 0.0f);
  numBytes += cDelay_init(this, &cDelay_lTJhNZyo, 0.0f);
  numBytes += hTable_init(&hTable_OclzoPJK, 256);
  numBytes += cVar_init_f(&cVar_9Eb3tmuD, 14.0f);
  numBytes += cBinop_init(&cBinop_KstrMhDT, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Zusswma0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5oi11rA2, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_IwQWT02t, 14.0f);
  numBytes += cBinop_init(&cBinop_I3EqtalF, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_pcEgFWtP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QX53fJp6, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_LFYrGjlh, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_WM6o3Hsa, 1, -1);
  numBytes += cVar_init_f(&cVar_lHXpqZ8S, 0.2f);
  numBytes += cSlice_init(&cSlice_yayMp0xM, 1, -1);
  numBytes += cVar_init_f(&cVar_7Qn7u7Tm, 0.0f);
  numBytes += cSlice_init(&cSlice_pShmClXm, 1, -1);
  numBytes += cVar_init_f(&cVar_sLTXbIQu, 2.0f);
  numBytes += cSlice_init(&cSlice_IkXK1ekb, 1, -1);
  numBytes += cVar_init_f(&cVar_X1cRXdT8, 0.5f);
  numBytes += cVar_init_s(&cVar_n9c8wm9J, "del-1446-flanger-l");
  numBytes += sVarf_init(&sVarf_Bi2SnjfS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_tvFyZ1ua, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_bHHbWflu, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_BbUqUgB3, "del-1446-flanger-r");
  numBytes += sVarf_init(&sVarf_rnD4csW9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9L9OUyIT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Df7J1ILx, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_IDv03TVB, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Yav6vgpq, 0.0f);
  numBytes += hTable_init(&hTable_PJYILIsE, 256);
  numBytes += cDelay_init(this, &cDelay_gSIFzkNd, 0.0f);
  numBytes += cDelay_init(this, &cDelay_4gzxLjOQ, 0.0f);
  numBytes += hTable_init(&hTable_GNIhoEIA, 256);
  numBytes += cVar_init_f(&cVar_fsObeTET, 14.0f);
  numBytes += cBinop_init(&cBinop_PNDlZ0Cg, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_fctQKI10, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oxHaTdLu, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_MAAFHkxp, 14.0f);
  numBytes += cBinop_init(&cBinop_FQI4EkuL, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Yj8RlYNe, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_mi8KmQGX, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_I1M3vOrf, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_MCjqXPd0, 1, -1);
  numBytes += cVar_init_f(&cVar_b4Nm62TN, 0.2f);
  numBytes += cSlice_init(&cSlice_3y39WiZh, 1, -1);
  numBytes += cVar_init_f(&cVar_Y0GB0avi, 0.0f);
  numBytes += cSlice_init(&cSlice_ixOfrpiC, 1, -1);
  numBytes += cVar_init_f(&cVar_wIlU3KAM, 2.0f);
  numBytes += cSlice_init(&cSlice_y51Q6zje, 1, -1);
  numBytes += cVar_init_f(&cVar_oESQo6KC, 0.5f);
  numBytes += sVarf_init(&sVarf_otlHgdcg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1oncvnX1, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YYNItq1f, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_78x0NDZd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Cxcsl74I, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ez2Up39d, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_FL3NGR::~Heavy_WSTD_FL3NGR() {
  hTable_free(&hTable_ugBSGtxz);
  hTable_free(&hTable_g9CiPUI0);
  hTable_free(&hTable_6z2NtUSM);
  hTable_free(&hTable_OclzoPJK);
  hTable_free(&hTable_PJYILIsE);
  hTable_free(&hTable_GNIhoEIA);
}

HvTable *Heavy_WSTD_FL3NGR::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x7E84AE7C: return &hTable_ugBSGtxz; // del-1348-flanger-r
    case 0x8BC7EF65: return &hTable_g9CiPUI0; // del-1348-flanger-l
    case 0x67C454D4: return &hTable_6z2NtUSM; // del-1397-flanger-r
    case 0x578173CB: return &hTable_OclzoPJK; // del-1397-flanger-l
    case 0xB5F31EFF: return &hTable_PJYILIsE; // del-1446-flanger-r
    case 0xFB92DE56: return &hTable_GNIhoEIA; // del-1446-flanger-l
    default: return nullptr;
  }
}

void Heavy_WSTD_FL3NGR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Z86XltcP_sendMessage);
      break;
    }
    case 0xACE44B9C: { // High_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vu8wINB8_sendMessage);
      break;
    }
    case 0xA66E154B: { // High_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vd1XyD8s_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zixlxj8M_sendMessage);
      break;
    }
    case 0x49068FB0: { // High_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6DFuaBa7_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0KegT8Ac_sendMessage);
      break;
    }
    case 0xDDAB7A0: { // Low_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7d9HcMc8_sendMessage);
      break;
    }
    case 0xF8FE7D54: { // Low_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uWBxNaUV_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xXAhHCw9_sendMessage);
      break;
    }
    case 0x768962E9: { // Low_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wTjRZUTJ_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BNSvuuy6_sendMessage);
      break;
    }
    case 0x9B44FA2D: { // Mid_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_unUCiQo8_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eFCuS7K0_sendMessage);
      break;
    }
    case 0x30AE5EFB: { // Mid_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kEePgpOQ_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xCzqQyiK_sendMessage);
      break;
    }
    case 0x78CC8F6D: { // Mid_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Go0yT90z_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0LUeZyQb_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GAY1b0Bt_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pFe6T14Z_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tmnyX3XW_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wBqv8Ou7_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HzJhi2ne_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_o83bQATY_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7Isw8L87_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sle1xufc_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lCFJjZVP_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zLTiDhWk_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_m8NdkCPq_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0Dn9eBqH_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_u71Z8cMR_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bJ1fkOey_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nvv1XGiA_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_boCtf4m1_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rGnWJwbk_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cibF9YNj_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HXgLSvqP_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qRD9OFOm_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_h3MXS9q4_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_oqgybTl0_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xYV7alA4_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bgFhsBOw_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NfOix0kq_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Me8XRQJx_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_A9gjEfMR_sendMessage);
      break;
    }
    case 0xB9261D01: { // 1348-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_N0H3zxiS_sendMessage);
      break;
    }
    case 0x7B4AB7DC: { // 1348-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LMCR8fPO_sendMessage);
      break;
    }
    case 0xC21D5730: { // 1348-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kRvPqAri_sendMessage);
      break;
    }
    case 0x73E3A43F: { // 1348-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_48TMzmCA_sendMessage);
      break;
    }
    case 0x8020E246: { // 1397-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DchdlGoO_sendMessage);
      break;
    }
    case 0xDE6EF86C: { // 1397-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_t0HJbXBo_sendMessage);
      break;
    }
    case 0x4C9CDCA8: { // 1397-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TCcLvAMW_sendMessage);
      break;
    }
    case 0xB69DF8D2: { // 1397-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_i9A332Oy_sendMessage);
      break;
    }
    case 0x2ABB5D7C: { // 1446-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NrhDtSrB_sendMessage);
      break;
    }
    case 0xE9A86FE0: { // 1446-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2CwXRMKj_sendMessage);
      break;
    }
    case 0xC66A3021: { // 1446-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1Jv2ckr7_sendMessage);
      break;
    }
    case 0x64835C2: { // 1446-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0TQy762j_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_K6bO5Kha_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_FL3NGR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Feedback";
        info->hash = 0xACE44B9C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "High_Intensity";
        info->hash = 0xA66E154B;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 3: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 4: {
        info->name = "High_Speed";
        info->hash = 0x49068FB0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 5: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 6: {
        info->name = "Low_Feedback";
        info->hash = 0xDDAB7A0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 7: {
        info->name = "Low_Intensity";
        info->hash = 0xF8FE7D54;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 8: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 9: {
        info->name = "Low_Speed";
        info->hash = 0x768962E9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 10: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 11: {
        info->name = "Mid_Feedback";
        info->hash = 0x9B44FA2D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 13: {
        info->name = "Mid_Intensity";
        info->hash = 0x30AE5EFB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 14: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 15: {
        info->name = "Mid_Speed";
        info->hash = 0x78CC8F6D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 16;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_FL3NGR::cVar_kyIz4kXB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bQyOhodk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_bV0ALgs9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_o2D0IOsF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_DFir1q6w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_p5hqXWCD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_27tAIEXJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_piXqjs8L_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KZ2HUhy7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_j4qjop8i_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1nuVi8O8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_BIjiuZmE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_M4xV690U, 0, m, &cSlice_M4xV690U_sendMessage);
      break;
    }
    default: {
      cSwitchcase_zNNTY5rU_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_M4xV690U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_gazMsxIO_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_gazMsxIO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_9jXwFnbb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gazMsxIO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_gazMsxIO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pFe6T14Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_xtgz3lw3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_f3jafxa8_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Qra67SBu, 0, m, &cIf_Qra67SBu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_Qra67SBu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_jMYhk06E_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_fLAvcqQx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_EOuHJdca_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_BDZfouh9_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_kmIpUiHs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_rRpDcj6C, HV_BINOP_POW, 0, m, &cBinop_rRpDcj6C_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rRpDcj6C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_381XIGlW, 0, m, &cIf_381XIGlW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CJsBtros_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_oPnXOp9M_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_43g5tlDQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fLAvcqQx, 0, m, &cIf_fLAvcqQx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_S11Lk2nd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_dR9b1eC3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dR9b1eC3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fLAvcqQx, 1, m, &cIf_fLAvcqQx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BDZfouh9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_CJsBtros_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_EOuHJdca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_381XIGlW, 0, m, &cIf_381XIGlW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_oPnXOp9M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rRpDcj6C, HV_BINOP_POW, 1, m, &cBinop_rRpDcj6C_sendMessage);
  cMsg_kmIpUiHs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_381XIGlW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_qCqo5Gvc, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_f3jafxa8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Qra67SBu, 1, m, &cIf_Qra67SBu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_jMYhk06E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nhorBcs6, HV_BINOP_GREATER_THAN, 1, m, &cBinop_nhorBcs6_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_d9O6PL8B, HV_BINOP_EQ, 1, m, &cBinop_d9O6PL8B_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_C03aJHTQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_oksfO5pu, HV_BINOP_ADD, 0, m, &cBinop_oksfO5pu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_oksfO5pu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_S11Lk2nd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_43g5tlDQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_nhorBcs6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_381XIGlW, 1, m, &cIf_381XIGlW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_d9O6PL8B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_k0rtcry4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_k0rtcry4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_qCqo5Gvc, m);
}

void Heavy_WSTD_FL3NGR::cCast_abJrij89_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oksfO5pu, HV_BINOP_ADD, 1, m, &cBinop_oksfO5pu_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_nhorBcs6, HV_BINOP_GREATER_THAN, 0, m, &cBinop_nhorBcs6_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_d9O6PL8B, HV_BINOP_EQ, 0, m, &cBinop_d9O6PL8B_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ajijiRTn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xtgz3lw3, 0, m, &cVar_xtgz3lw3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_yPjkg6ya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_C03aJHTQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_PyVGAy3t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_wJmMEb4q_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_ObcdliBW, 0, m, &cIf_ObcdliBW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_ObcdliBW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_UewDSzKH_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_K0QhnQkf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_FLWJBZwR_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_NGIqk3en_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_LXFHzceT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_hagsf17Z, HV_BINOP_POW, 0, m, &cBinop_hagsf17Z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_hagsf17Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OxTbvMoF, 0, m, &cIf_OxTbvMoF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4i9UQlCv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_x4E7Fvke_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_2KgtCJ68_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_K0QhnQkf, 0, m, &cIf_K0QhnQkf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_OZJBEYzb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_UOW7l8hE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_UOW7l8hE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_K0QhnQkf, 1, m, &cIf_K0QhnQkf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NGIqk3en_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_4i9UQlCv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_FLWJBZwR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_OxTbvMoF, 0, m, &cIf_OxTbvMoF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_x4E7Fvke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hagsf17Z, HV_BINOP_POW, 1, m, &cBinop_hagsf17Z_sendMessage);
  cMsg_LXFHzceT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_OxTbvMoF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_JWPZE7wS_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XQIsGmqg_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_XaLsqisP_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_wJmMEb4q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ObcdliBW, 1, m, &cIf_ObcdliBW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_UewDSzKH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R6XhYeIF, HV_BINOP_GREATER_THAN, 1, m, &cBinop_R6XhYeIF_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_SfQrZ12p, HV_BINOP_EQ, 1, m, &cBinop_SfQrZ12p_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_CkIgGrrC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7dsET4ak, HV_BINOP_ADD, 0, m, &cBinop_7dsET4ak_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7dsET4ak_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OZJBEYzb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2KgtCJ68_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_R6XhYeIF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OxTbvMoF, 1, m, &cIf_OxTbvMoF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SfQrZ12p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5AhQEvOW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_5AhQEvOW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_JWPZE7wS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XQIsGmqg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_XaLsqisP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_OtVrfREO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7dsET4ak, HV_BINOP_ADD, 1, m, &cBinop_7dsET4ak_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_R6XhYeIF, HV_BINOP_GREATER_THAN, 0, m, &cBinop_R6XhYeIF_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_SfQrZ12p, HV_BINOP_EQ, 0, m, &cBinop_SfQrZ12p_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_f5bunBO9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PyVGAy3t, 0, m, &cVar_PyVGAy3t_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_qGQfzsHF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CkIgGrrC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_8LVHlTis_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_weBN1vPg_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_MVTiJahZ, 0, m, &cIf_MVTiJahZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_MVTiJahZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_84WUP9OH_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_Shvo7DDa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_q6EjXAPu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_bgczToHz_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_O2na46uk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_U8GJWqtA, HV_BINOP_POW, 0, m, &cBinop_U8GJWqtA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_U8GJWqtA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_a17vga5e, 0, m, &cIf_a17vga5e_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_hUgRbaMq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_litC3jkw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_g20hPR5C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Shvo7DDa, 0, m, &cIf_Shvo7DDa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_LW1C8dMz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_A8Dqt9mj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_A8Dqt9mj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Shvo7DDa, 1, m, &cIf_Shvo7DDa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bgczToHz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_hUgRbaMq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_q6EjXAPu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_a17vga5e, 0, m, &cIf_a17vga5e_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_litC3jkw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U8GJWqtA, HV_BINOP_POW, 1, m, &cBinop_U8GJWqtA_sendMessage);
  cMsg_O2na46uk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_a17vga5e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_q6QfuSRd, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_weBN1vPg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MVTiJahZ, 1, m, &cIf_MVTiJahZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_84WUP9OH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eFQBZzd9, HV_BINOP_GREATER_THAN, 1, m, &cBinop_eFQBZzd9_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_tHDQrMuE, HV_BINOP_EQ, 1, m, &cBinop_tHDQrMuE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_0jFzmiaG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_mYYlOmys, HV_BINOP_ADD, 0, m, &cBinop_mYYlOmys_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mYYlOmys_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LW1C8dMz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g20hPR5C_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_eFQBZzd9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_a17vga5e, 1, m, &cIf_a17vga5e_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_tHDQrMuE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KXIjj76n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_KXIjj76n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_q6QfuSRd, m);
}

void Heavy_WSTD_FL3NGR::cCast_PG2fEH8i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mYYlOmys, HV_BINOP_ADD, 1, m, &cBinop_mYYlOmys_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_eFQBZzd9, HV_BINOP_GREATER_THAN, 0, m, &cBinop_eFQBZzd9_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_tHDQrMuE, HV_BINOP_EQ, 0, m, &cBinop_tHDQrMuE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_6QydghA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8LVHlTis, 0, m, &cVar_8LVHlTis_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_xfzgdn3W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0jFzmiaG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_k1OEIxfI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_cAzZHvSy, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cSwitchcase_GtLkLhwI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_eoKsuCuD, 0, m, &cSlice_eoKsuCuD_sendMessage);
      break;
    }
    default: {
      cSwitchcase_87SiPQJF_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_eoKsuCuD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Fbxz2sN3_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Fbxz2sN3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_E4sIX6uI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Fbxz2sN3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_Fbxz2sN3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0LUeZyQb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_87SiPQJF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_h5a1Jp1v, 0, m, &cSlice_h5a1Jp1v_sendMessage);
      break;
    }
    default: {
      cSwitchcase_BIjiuZmE_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_h5a1Jp1v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_GPM9lGaE_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_GPM9lGaE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_YPbLKPzE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GPM9lGaE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_GPM9lGaE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wBqv8Ou7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_zNNTY5rU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_1R05djxm, 0, m, &cSlice_1R05djxm_sendMessage);
      break;
    }
    default: {
      cSwitchcase_TWOszjKC_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_1R05djxm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_3c0yUcND_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_3c0yUcND_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_IgyCuGKC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3c0yUcND_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_3c0yUcND_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GAY1b0Bt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_TWOszjKC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_wVFvirho, 0, m, &cSlice_wVFvirho_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_wVFvirho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_oBBLM8cj_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_oBBLM8cj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_a9yTzArx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_oBBLM8cj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_oBBLM8cj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tmnyX3XW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_skHAkQDs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_L9LOYhNx, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_VClrUJoN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VO4x8yeb, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_uGRwOOcI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3mvtgJO8, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_R2jLwWMy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lVwKnrMZ, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_XQLShPLQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wJeue3mA, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_mQQZxJLU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_V2Ifyl8c_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_V2Ifyl8c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sWE6o7lk, HV_BINOP_DIVIDE, 1, m, &cBinop_sWE6o7lk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_K8XLwzLw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_5Np0wwhV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_WDB5IWBm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_o83xS2uz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_5Np0wwhV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WDB5IWBm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sWE6o7lk, HV_BINOP_DIVIDE, 0, m, &cBinop_sWE6o7lk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_K8XLwzLw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_o83xS2uz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_sWE6o7lk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_obv1cpWu, HV_BINOP_MULTIPLY, 1, m, &cBinop_obv1cpWu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_obv1cpWu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vj4bjHP1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HUgmUMJ1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_aisXBtWb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ZkCTjyY0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_tYSCfJOj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6PWVysy5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_XYVKgint_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_h97fDdFu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_h97fDdFu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_obv1cpWu, HV_BINOP_MULTIPLY, 0, m, &cBinop_obv1cpWu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zI0FFSG0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_dTRtKowX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dTRtKowX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_h1nmufZW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_dStjhzII_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lQDm0a6o, 1, m, &cVar_lQDm0a6o_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_lQDm0a6o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YOBxgpjC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_DNlLhtVH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vtpopmVP, HV_BINOP_MULTIPLY, 1, m, &cBinop_vtpopmVP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TZkxMGLe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_DNlLhtVH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_S8mCJubj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_2il4bxOi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2il4bxOi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FLnoLTs9, HV_BINOP_MULTIPLY, 1, m, &cBinop_FLnoLTs9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ccdrN7M9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hQCaSHMn, HV_BINOP_MULTIPLY, 1, m, &cBinop_hQCaSHMn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yku4Mtjj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ccdrN7M9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WX4fAEWt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E12duryJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_E12duryJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_amCohVK2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_qGKI8Jml_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qGKI8Jml_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XgTvaRxg, HV_BINOP_MULTIPLY, 1, m, &cBinop_XgTvaRxg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_vJzLuHij_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NRVzCQZC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_XYVKgint_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qhUvff5W_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_e1gG4YNn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_zI0FFSG0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_HUgmUMJ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_tYSCfJOj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_vj4bjHP1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_aisXBtWb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_ZkCTjyY0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7Isw8L87_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_6PWVysy5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_o83bQATY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_42EhxKYE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HzJhi2ne_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_h1nmufZW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_WhGrhV8L_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WhGrhV8L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_40imlosr, HV_BINOP_MULTIPLY, 1, m, &cBinop_40imlosr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_40imlosr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_L1U7mUK9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_L1U7mUK9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_42EhxKYE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_YOBxgpjC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_NSgQJdaA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NSgQJdaA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pWu4w7t3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oaZaz1fu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nfWL0PFk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_x3MilNVn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HhuzoKsS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ip91SYqY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vtpopmVP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_skHAkQDs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_FLnoLTs9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VClrUJoN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_hQCaSHMn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uGRwOOcI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_E12duryJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_R2jLwWMy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_XgTvaRxg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XQLShPLQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_jTugq0qO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vJzLuHij, 0, m, &cVar_vJzLuHij_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_vVB51X9r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_e1gG4YNn, 1, m, &cVar_e1gG4YNn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ip91SYqY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vtpopmVP, HV_BINOP_MULTIPLY, 0, m, &cBinop_vtpopmVP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_nfWL0PFk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E12duryJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_E12duryJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_HhuzoKsS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FLnoLTs9, HV_BINOP_MULTIPLY, 0, m, &cBinop_FLnoLTs9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_oaZaz1fu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XgTvaRxg, HV_BINOP_MULTIPLY, 0, m, &cBinop_XgTvaRxg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_x3MilNVn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hQCaSHMn, HV_BINOP_MULTIPLY, 0, m, &cBinop_hQCaSHMn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_pWu4w7t3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_NRVzCQZC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_e1gG4YNn, 0, m, &cVar_e1gG4YNn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_qhUvff5W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lQDm0a6o, 0, m, &cVar_lQDm0a6o_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_zFQcyuaF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_biSOmqb0, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_4rU6OODz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kCX9mIRq, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_Ijlnek8F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TPv0Li4m, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_4R9DxbnX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9rPNVi0c, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_xD8bYRol_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Tvdt77HM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_Tvdt77HM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XkKblgGM, HV_BINOP_DIVIDE, 1, m, &cBinop_XkKblgGM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4pGtlXb9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_jvamv06X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_p4izaiih_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_7p2uh4tw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_jvamv06X_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_p4izaiih_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XkKblgGM, HV_BINOP_DIVIDE, 0, m, &cBinop_XkKblgGM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_4pGtlXb9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7p2uh4tw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_XkKblgGM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iLu6U0Z5, HV_BINOP_MULTIPLY, 1, m, &cBinop_iLu6U0Z5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_iLu6U0Z5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_P4FunIXN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_atk7XxuC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_KAtcL4X1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_s6rTtYPd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_hAC8vzst_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_scxWvJk0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Q8kJ1LK1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_IALQ3ld8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_IALQ3ld8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iLu6U0Z5, HV_BINOP_MULTIPLY, 0, m, &cBinop_iLu6U0Z5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9deVt7bs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_qWihJJ3r_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qWihJJ3r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_V7vntdwv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_sW4I1pcw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NNn4fcxp, HV_BINOP_MULTIPLY, 1, m, &cBinop_NNn4fcxp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_UMj0CvFD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ac0YlViY, 1, m, &cVar_ac0YlViY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fz6QRSop_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BAQE0v5T, HV_BINOP_MULTIPLY, 1, m, &cBinop_BAQE0v5T_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_c2BZdrFE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_gDFELZGF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gDFELZGF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k8AAdmHG, HV_BINOP_MULTIPLY, 1, m, &cBinop_k8AAdmHG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_ac0YlViY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cX0S2UIM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_pg8KPQfj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yaJ0f87v_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_Q8kJ1LK1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JEUtQabz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_KtM8pUGB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_9deVt7bs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_P4FunIXN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_KAtcL4X1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_atk7XxuC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_hAC8vzst_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_s6rTtYPd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zLTiDhWk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_scxWvJk0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lCFJjZVP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_oje0aVDP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_sle1xufc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_V7vntdwv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_HZwTWU1u_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HZwTWU1u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZksDLrDq, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZksDLrDq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZksDLrDq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_FunJrFDJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FunJrFDJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_oje0aVDP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_cX0S2UIM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_AdBxkeHY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_AdBxkeHY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_b0rxRpRr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fUoCQbMI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8m1oAtbN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_m4qFUpfe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_oDKf9Q5z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zFQcyuaF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_NNn4fcxp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4rU6OODz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_BAQE0v5T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ijlnek8F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_k8AAdmHG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4R9DxbnX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_E58lgcHD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KtM8pUGB, 1, m, &cVar_KtM8pUGB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ohjOIWAZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pg8KPQfj, 0, m, &cVar_pg8KPQfj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_JEUtQabz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ac0YlViY, 0, m, &cVar_ac0YlViY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_yaJ0f87v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KtM8pUGB, 0, m, &cVar_KtM8pUGB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_m4qFUpfe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oDKf9Q5z, HV_BINOP_MULTIPLY, 0, m, &cBinop_oDKf9Q5z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_b0rxRpRr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k8AAdmHG, HV_BINOP_MULTIPLY, 0, m, &cBinop_k8AAdmHG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_8m1oAtbN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NNn4fcxp, HV_BINOP_MULTIPLY, 0, m, &cBinop_NNn4fcxp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_fUoCQbMI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BAQE0v5T, HV_BINOP_MULTIPLY, 0, m, &cBinop_BAQE0v5T_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_jA9raD8T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CULt5gCq, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_xsibdVA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Nh6qBen3, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_RarDbwLi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8wMMkJl4, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_CHiTR7Zx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vsvWMAPR, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_DTM9SMi1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MvQJcrV1, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_0YKuZV51_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_gMvZ0x53_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_gMvZ0x53_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BVqsxjLw, HV_BINOP_DIVIDE, 1, m, &cBinop_BVqsxjLw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3oLsG39B_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_HmRCEQrp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_B4BoORsl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_qc6GmjJO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_HmRCEQrp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_B4BoORsl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BVqsxjLw, HV_BINOP_DIVIDE, 0, m, &cBinop_BVqsxjLw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_3oLsG39B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qc6GmjJO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_BVqsxjLw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5r43D77g, HV_BINOP_MULTIPLY, 1, m, &cBinop_5r43D77g_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5r43D77g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6Ko6Xlt7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_k6VQ6aMD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_J9I9UhPJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vF1wGCs4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_AbFXR3W6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XIopFoRY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_IbCptWUg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_BC7f9JPr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BC7f9JPr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5r43D77g, HV_BINOP_MULTIPLY, 0, m, &cBinop_5r43D77g_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qkOKnuAj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_WT7K1Lyc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WT7K1Lyc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IbPVcdJG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_nKKMCgCE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MpQfg6MK, HV_BINOP_MULTIPLY, 1, m, &cBinop_MpQfg6MK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_REneCejQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_pMsxbALR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pMsxbALR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_nKKMCgCE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_0mhG2PMo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_TVUrtzhK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TVUrtzhK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NzS2jIwL, HV_BINOP_MULTIPLY, 1, m, &cBinop_NzS2jIwL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Yyzkz63d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EtF3Jho8, HV_BINOP_MULTIPLY, 1, m, &cBinop_EtF3Jho8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_k1aTiLKX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_QW343Ks2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QW343Ks2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Yyzkz63d_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_k5CZjske_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1U0Mssol, 1, m, &cVar_1U0Mssol_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_y2XFJUst_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ELNVIXTx, HV_BINOP_MULTIPLY, 1, m, &cBinop_ELNVIXTx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_N5oeu0KN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Ntt3XRZx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Ntt3XRZx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HgL7xnTf, HV_BINOP_MULTIPLY, 1, m, &cBinop_HgL7xnTf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_1U0Mssol_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_owKGJX84_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_MaQQSZWn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_x9b1OSVH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_IbCptWUg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sgrNhXu4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_BOJSm5ik_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_qkOKnuAj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_k6VQ6aMD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_AbFXR3W6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_6Ko6Xlt7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_J9I9UhPJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_vF1wGCs4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_u71Z8cMR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_XIopFoRY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0Dn9eBqH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_2hgTZRDE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_m8NdkCPq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_IbPVcdJG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_qyC7c71E_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qyC7c71E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PmjG30eZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_PmjG30eZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PmjG30eZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_2pEr4OfH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2pEr4OfH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_2hgTZRDE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_owKGJX84_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_oOFuUJlX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_oOFuUJlX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sZSOQqUe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6PNJn4Qy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_n70wykCs_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MjZM3ZEi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MVRSL5ue_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_K0MwOBnE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_MpQfg6MK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jA9raD8T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_NzS2jIwL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xsibdVA0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_EtF3Jho8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RarDbwLi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ELNVIXTx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CHiTR7Zx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_HgL7xnTf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DTM9SMi1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_2anmwOy4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BOJSm5ik, 1, m, &cVar_BOJSm5ik_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_koSdhDei_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MaQQSZWn, 0, m, &cVar_MaQQSZWn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_K0MwOBnE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MpQfg6MK, HV_BINOP_MULTIPLY, 0, m, &cBinop_MpQfg6MK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_n70wykCs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ELNVIXTx, HV_BINOP_MULTIPLY, 0, m, &cBinop_ELNVIXTx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_MVRSL5ue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NzS2jIwL, HV_BINOP_MULTIPLY, 0, m, &cBinop_NzS2jIwL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_6PNJn4Qy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HgL7xnTf, HV_BINOP_MULTIPLY, 0, m, &cBinop_HgL7xnTf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_MjZM3ZEi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EtF3Jho8, HV_BINOP_MULTIPLY, 0, m, &cBinop_EtF3Jho8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_sZSOQqUe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_sgrNhXu4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1U0Mssol, 0, m, &cVar_1U0Mssol_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_x9b1OSVH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BOJSm5ik, 0, m, &cVar_BOJSm5ik_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_JWPZE7wS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_k1OEIxfI, 1, m, &cIf_k1OEIxfI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_AAw1FJ4f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_cAzZHvSy, m);
}

void Heavy_WSTD_FL3NGR::cBinop_XQIsGmqg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AAw1FJ4f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_XaLsqisP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_k1OEIxfI, 0, m, &cIf_k1OEIxfI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_0ouUQIJ3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Fmj1G8qm, 0, m, &cSlice_Fmj1G8qm_sendMessage);
      break;
    }
    default: {
      cSwitchcase_8wRZAZ9o_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_Fmj1G8qm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_wnt40hMW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_wnt40hMW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_GzeUIWbB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wnt40hMW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_wnt40hMW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_boCtf4m1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_WtRAwYBO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_qYf7uuIW_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_nFLhojuB, 0, m, &cIf_nFLhojuB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_nFLhojuB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_GP3Kbvqc_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_cOMqDXUF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_kClJGSl2_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_u6cXqNYz_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_dwyXMSEz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1nM3FD1h, HV_BINOP_POW, 0, m, &cBinop_1nM3FD1h_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1nM3FD1h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4w4UkMci, 0, m, &cIf_4w4UkMci_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_aWDdsMqV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_xRztjdxZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_gJzdEtUW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cOMqDXUF, 0, m, &cIf_cOMqDXUF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_zzUZfvFr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_VADoHZOM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VADoHZOM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cOMqDXUF, 1, m, &cIf_cOMqDXUF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_u6cXqNYz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_aWDdsMqV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_kClJGSl2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_4w4UkMci, 0, m, &cIf_4w4UkMci_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xRztjdxZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1nM3FD1h, HV_BINOP_POW, 1, m, &cBinop_1nM3FD1h_sendMessage);
  cMsg_dwyXMSEz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_4w4UkMci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_asFtP1wS, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_qYf7uuIW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nFLhojuB, 1, m, &cIf_nFLhojuB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_GP3Kbvqc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5l8dcbte, HV_BINOP_GREATER_THAN, 1, m, &cBinop_5l8dcbte_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_S6ae0NqB, HV_BINOP_EQ, 1, m, &cBinop_S6ae0NqB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_N3XYilk6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ebcgblkq, HV_BINOP_ADD, 0, m, &cBinop_Ebcgblkq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Ebcgblkq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zzUZfvFr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gJzdEtUW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5l8dcbte_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4w4UkMci, 1, m, &cIf_4w4UkMci_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_S6ae0NqB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cleHHSGI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_cleHHSGI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_asFtP1wS, m);
}

void Heavy_WSTD_FL3NGR::cCast_uwoPhCRp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_N3XYilk6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_MQUM4tsT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ebcgblkq, HV_BINOP_ADD, 1, m, &cBinop_Ebcgblkq_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5l8dcbte, HV_BINOP_GREATER_THAN, 0, m, &cBinop_5l8dcbte_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_S6ae0NqB, HV_BINOP_EQ, 0, m, &cBinop_S6ae0NqB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_L5VUM8on_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WtRAwYBO, 0, m, &cVar_WtRAwYBO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_UQfqt1ez_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Fc1dD2ah_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_vGZ0IMbu, 0, m, &cIf_vGZ0IMbu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_vGZ0IMbu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_hmI9dEZn_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_ITbinu90_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_xuil8sQN_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_cpWF3yvs_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_Ud45GvNB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8Meatvby, HV_BINOP_POW, 0, m, &cBinop_8Meatvby_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8Meatvby_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_96FoSolo, 0, m, &cIf_96FoSolo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_I3YRH8jB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_2qcKRqjW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ICqiic6X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_XmpMkBO9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_9iiPydCh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ITbinu90, 0, m, &cIf_ITbinu90_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XmpMkBO9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ITbinu90, 1, m, &cIf_ITbinu90_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cpWF3yvs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_I3YRH8jB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_xuil8sQN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_96FoSolo, 0, m, &cIf_96FoSolo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2qcKRqjW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8Meatvby, HV_BINOP_POW, 1, m, &cBinop_8Meatvby_sendMessage);
  cMsg_Ud45GvNB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_96FoSolo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_NjKgVIir_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Vp2E3sPq_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_x9taUAGP_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_Fc1dD2ah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vGZ0IMbu, 1, m, &cIf_vGZ0IMbu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_hmI9dEZn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3ADkGj1n, HV_BINOP_GREATER_THAN, 1, m, &cBinop_3ADkGj1n_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_AWu3ugC2, HV_BINOP_EQ, 1, m, &cBinop_AWu3ugC2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_qsUyEwhv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_i0MPQoPF, HV_BINOP_ADD, 0, m, &cBinop_i0MPQoPF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_i0MPQoPF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ICqiic6X_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9iiPydCh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3ADkGj1n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_96FoSolo, 1, m, &cIf_96FoSolo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_AWu3ugC2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wMPpKFyJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_wMPpKFyJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_NjKgVIir_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Vp2E3sPq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_x9taUAGP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_BBb62GPd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UQfqt1ez, 0, m, &cVar_UQfqt1ez_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_jjzR0LBs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qsUyEwhv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_lchXMnT7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_i0MPQoPF, HV_BINOP_ADD, 1, m, &cBinop_i0MPQoPF_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_3ADkGj1n, HV_BINOP_GREATER_THAN, 0, m, &cBinop_3ADkGj1n_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_AWu3ugC2, HV_BINOP_EQ, 0, m, &cBinop_AWu3ugC2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_KQnU6oAw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_j0iOCrJR_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_pqMge7z9, 0, m, &cIf_pqMge7z9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_pqMge7z9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_YGuXU8SP_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_HBRG1S6s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_IaXIJ92Y_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_5yG381Nf_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_Piww8jH7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_KbsL4hZy, HV_BINOP_POW, 0, m, &cBinop_KbsL4hZy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KbsL4hZy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eRH0UaJQ, 0, m, &cIf_eRH0UaJQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TsOBUWcE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_RVhGcYEM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_UPPedU4B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HBRG1S6s, 0, m, &cIf_HBRG1S6s_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_IK8NOzCc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_G3lNISuN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_G3lNISuN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HBRG1S6s, 1, m, &cIf_HBRG1S6s_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5yG381Nf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_TsOBUWcE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_IaXIJ92Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_eRH0UaJQ, 0, m, &cIf_eRH0UaJQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RVhGcYEM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KbsL4hZy, HV_BINOP_POW, 1, m, &cBinop_KbsL4hZy_sendMessage);
  cMsg_Piww8jH7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_eRH0UaJQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_B8hZEEEN, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_j0iOCrJR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pqMge7z9, 1, m, &cIf_pqMge7z9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YGuXU8SP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HE77MH3R, HV_BINOP_GREATER_THAN, 1, m, &cBinop_HE77MH3R_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_kn8ShmFm, HV_BINOP_EQ, 1, m, &cBinop_kn8ShmFm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_cKTwKtTX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Y68vpTt5, HV_BINOP_ADD, 0, m, &cBinop_Y68vpTt5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Y68vpTt5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IK8NOzCc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UPPedU4B_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HE77MH3R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eRH0UaJQ, 1, m, &cIf_eRH0UaJQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_kn8ShmFm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QkeLg7Ou_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_QkeLg7Ou_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_B8hZEEEN, m);
}

void Heavy_WSTD_FL3NGR::cCast_D4gyoUkk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KQnU6oAw, 0, m, &cVar_KQnU6oAw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ciYNe0FJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cKTwKtTX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_JoPodbR0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Y68vpTt5, HV_BINOP_ADD, 1, m, &cBinop_Y68vpTt5_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HE77MH3R, HV_BINOP_GREATER_THAN, 0, m, &cBinop_HE77MH3R_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_kn8ShmFm, HV_BINOP_EQ, 0, m, &cBinop_kn8ShmFm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_rvXf6ZS5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_eq5j0DXF, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cSwitchcase_7qtxaFG0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_vS4GJ3eU, 0, m, &cSlice_vS4GJ3eU_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Ol2NSYR3_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_vS4GJ3eU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_a2Wr4WXt_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_a2Wr4WXt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_oiHyJx6A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_a2Wr4WXt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_a2Wr4WXt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bJ1fkOey_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_Ol2NSYR3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_msgjMxms, 0, m, &cSlice_msgjMxms_sendMessage);
      break;
    }
    default: {
      cSwitchcase_0ouUQIJ3_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_msgjMxms_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_NyuRL0bw_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_NyuRL0bw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_gYSnhorf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NyuRL0bw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_NyuRL0bw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cibF9YNj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_8wRZAZ9o_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_gXpUHbRw, 0, m, &cSlice_gXpUHbRw_sendMessage);
      break;
    }
    default: {
      cSwitchcase_AzGBp2So_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_gXpUHbRw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_kXlzrlH8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_kXlzrlH8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_UlbVWQvj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_kXlzrlH8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_kXlzrlH8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nvv1XGiA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_AzGBp2So_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_hnSHIGIk, 0, m, &cSlice_hnSHIGIk_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_hnSHIGIk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_xCIxCgA1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_xCIxCgA1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_vkD0wuso_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xCIxCgA1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_xCIxCgA1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rGnWJwbk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_61mYSOLX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oMMpsgRW, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_1uKfSgeZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nHA1MKoK, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_CMfvY7yY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WS07jkZu, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_pqinhqiy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AFY8em8B, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_0iimwgUJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kIPvVVrh, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_iWUwEiP1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_SGrGMdTY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_SGrGMdTY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qVIfFBQT, HV_BINOP_DIVIDE, 1, m, &cBinop_qVIfFBQT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qR0sagFy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_zzUU7QKN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_G5YSv3z0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_83Rm8RX3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_zzUU7QKN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_G5YSv3z0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qVIfFBQT, HV_BINOP_DIVIDE, 0, m, &cBinop_qVIfFBQT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_qR0sagFy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_83Rm8RX3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_qVIfFBQT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jzUAkt0C, HV_BINOP_MULTIPLY, 1, m, &cBinop_jzUAkt0C_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_jzUAkt0C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2k13UkO1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tNwGvMPr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_MBABXjj1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_uDpPtuFe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_NujdiIyc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_k13WlwbO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_FBeJvhHS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_NCkkuIhC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NCkkuIhC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jzUAkt0C, HV_BINOP_MULTIPLY, 0, m, &cBinop_jzUAkt0C_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_z0ACS39O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_IwEkfDHx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_IwEkfDHx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GlO5TIC2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_WRV4QElB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ya3EBSnd, 1, m, &cVar_ya3EBSnd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_ya3EBSnd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jRLidiNk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_zCkk87r0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_teZHzp1l, HV_BINOP_MULTIPLY, 1, m, &cBinop_teZHzp1l_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gNEN1193_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_zCkk87r0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_AcIniHJV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_qaxe8Bit_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qaxe8Bit_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sbnt4hoR, HV_BINOP_MULTIPLY, 1, m, &cBinop_sbnt4hoR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9Y2Alevm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_usyukM1a, HV_BINOP_MULTIPLY, 1, m, &cBinop_usyukM1a_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YFDOoocC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_9Y2Alevm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ras3Ysgw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iqMkFVfr, HV_BINOP_MULTIPLY, 1, m, &cBinop_iqMkFVfr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_cWpB0Lpk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_im4T6Eyv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_im4T6Eyv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QgpSYnW4, HV_BINOP_MULTIPLY, 1, m, &cBinop_QgpSYnW4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_njdIrW7j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QGfOrc6o_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_FBeJvhHS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rdbMA8iz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_3At2mtSC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_z0ACS39O_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_2k13UkO1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_MBABXjj1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_tNwGvMPr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_NujdiIyc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_uDpPtuFe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_h3MXS9q4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_k13WlwbO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qRD9OFOm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_u67LQiWu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HXgLSvqP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_GlO5TIC2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_yfWYW6EJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yfWYW6EJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z8a9pmxQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_Z8a9pmxQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Z8a9pmxQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_rYl946pM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rYl946pM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_u67LQiWu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_jRLidiNk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_0OmzsExa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0OmzsExa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_w7o31ze6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HSeYTHtR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YkSYkTUm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FmbDHwK2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3HBvRsko_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9Xo75pHP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_teZHzp1l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_61mYSOLX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_sbnt4hoR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1uKfSgeZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_usyukM1a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CMfvY7yY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_iqMkFVfr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pqinhqiy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_QgpSYnW4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0iimwgUJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_Eureurc4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3At2mtSC, 1, m, &cVar_3At2mtSC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_KB2k2QlF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_njdIrW7j, 0, m, &cVar_njdIrW7j_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_9Xo75pHP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_teZHzp1l, HV_BINOP_MULTIPLY, 0, m, &cBinop_teZHzp1l_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_YkSYkTUm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iqMkFVfr, HV_BINOP_MULTIPLY, 0, m, &cBinop_iqMkFVfr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_3HBvRsko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sbnt4hoR, HV_BINOP_MULTIPLY, 0, m, &cBinop_sbnt4hoR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_HSeYTHtR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QgpSYnW4, HV_BINOP_MULTIPLY, 0, m, &cBinop_QgpSYnW4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_FmbDHwK2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_usyukM1a, HV_BINOP_MULTIPLY, 0, m, &cBinop_usyukM1a_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_w7o31ze6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_rdbMA8iz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ya3EBSnd, 0, m, &cVar_ya3EBSnd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_QGfOrc6o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3At2mtSC, 0, m, &cVar_3At2mtSC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_GXnhAowk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZYFwohQJ, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_Duj4LOd5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_k4k9iJ3E, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_ucbuNMWw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UqCvs45e, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_03ECk0yO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8ezbnnkl, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_IaFLwMq4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_zWG5OJDL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_zWG5OJDL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XC6rkoSz, HV_BINOP_DIVIDE, 1, m, &cBinop_XC6rkoSz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NqE597LN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_6dVDnRNs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_0ZPKePN3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_DE7MxduH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_6dVDnRNs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0ZPKePN3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XC6rkoSz, HV_BINOP_DIVIDE, 0, m, &cBinop_XC6rkoSz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_NqE597LN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DE7MxduH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_XC6rkoSz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QB3Uqh9M, HV_BINOP_MULTIPLY, 1, m, &cBinop_QB3Uqh9M_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QB3Uqh9M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GU0sVy0a_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QMz7LaWh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_SFwyxJP2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_uz34FfNx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_1IZsBR0W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_K7TAea8Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_MpjOJ6n5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_sx7ul379_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_sx7ul379_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QB3Uqh9M, HV_BINOP_MULTIPLY, 0, m, &cBinop_QB3Uqh9M_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BoUggNud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_mZmQXwCG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mZmQXwCG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uSzhPGIc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_XaVJZQF6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_r93F0qgQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_r93F0qgQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bqTar5Pg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5v1nkOTQ, 1, m, &cVar_5v1nkOTQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_x8OHKFvC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HokiqOyQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_HokiqOyQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_MgwFaBBO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_HkkwMkip_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HkkwMkip_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ypBW4VAx, HV_BINOP_MULTIPLY, 1, m, &cBinop_ypBW4VAx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_5v1nkOTQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8108InuH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_jdKsWt58_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sffjKQof_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_MpjOJ6n5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9UxzKyN1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_PLhntHKt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_BoUggNud_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_QMz7LaWh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_1IZsBR0W_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_GU0sVy0a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_SFwyxJP2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_uz34FfNx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bgFhsBOw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_K7TAea8Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xYV7alA4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_o3CzIYrh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_oqgybTl0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_uSzhPGIc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_aznZ0Im9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_aznZ0Im9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EvuojrHh, HV_BINOP_MULTIPLY, 1, m, &cBinop_EvuojrHh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_EvuojrHh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_7bmHnGq9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7bmHnGq9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_o3CzIYrh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_8108InuH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_iCdX9lRU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_iCdX9lRU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jc9xCeWK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oY3ISYwX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OCYbgAXu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NDdiYtSb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mFRVKTdQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GXnhAowk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_r93F0qgQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Duj4LOd5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_HokiqOyQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ucbuNMWw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ypBW4VAx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_03ECk0yO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_lfcD4SkC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PLhntHKt, 1, m, &cVar_PLhntHKt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Idtpm9DY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jdKsWt58, 0, m, &cVar_jdKsWt58_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_sffjKQof_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PLhntHKt, 0, m, &cVar_PLhntHKt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_9UxzKyN1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5v1nkOTQ, 0, m, &cVar_5v1nkOTQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_OCYbgAXu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_r93F0qgQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_r93F0qgQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_oY3ISYwX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HokiqOyQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_HokiqOyQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_NDdiYtSb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mFRVKTdQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_mFRVKTdQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_jc9xCeWK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ypBW4VAx, HV_BINOP_MULTIPLY, 0, m, &cBinop_ypBW4VAx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_FvbZqGm5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uxgUaP1E, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_BZfQ7olH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_geS9R11w, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_onpJazTo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rcW4s83b, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_WHV92ohc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3txu3z0o, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_xDraMB6N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_siPf779k, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_HJv509gC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_8pg9vthI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_8pg9vthI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_INo2Ydgt, HV_BINOP_DIVIDE, 1, m, &cBinop_INo2Ydgt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FZiso3Jg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_VdvAIg0K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_vWTnDO1e_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_NUugMx80_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_VdvAIg0K_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vWTnDO1e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_INo2Ydgt, HV_BINOP_DIVIDE, 0, m, &cBinop_INo2Ydgt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_FZiso3Jg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NUugMx80_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_INo2Ydgt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qfzsyu7e, HV_BINOP_MULTIPLY, 1, m, &cBinop_Qfzsyu7e_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Qfzsyu7e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pCxiQySz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7W8PPKSr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_FXNz7HYd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_C9JJ9gx0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_JMwkDbWl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Gkn9w7t4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_PZqOE8ZQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_zgkAccSW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zgkAccSW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qfzsyu7e, HV_BINOP_MULTIPLY, 0, m, &cBinop_Qfzsyu7e_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SKUl5GxE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_hppEVf7Q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_hppEVf7Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_usQFMyUn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_kN10NrBY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2yQtAL5P, HV_BINOP_MULTIPLY, 1, m, &cBinop_2yQtAL5P_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_nqx9Qr00_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_CQLtSHDa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CQLtSHDa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_kN10NrBY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_tYyRD681_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_3FoykO7P_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3FoykO7P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5dFVdY61, HV_BINOP_MULTIPLY, 1, m, &cBinop_5dFVdY61_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_32Q6wgB9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_d2nUouNT, HV_BINOP_MULTIPLY, 1, m, &cBinop_d2nUouNT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_3cnVvdgM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_byDFwUTC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_byDFwUTC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_32Q6wgB9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9GIsLuav_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KGm2VA63, 1, m, &cVar_KGm2VA63_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9msTS3hE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2JPJfJKR, HV_BINOP_MULTIPLY, 1, m, &cBinop_2JPJfJKR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_s0VoMFib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_qH5iSuEa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qH5iSuEa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5Gw5yqSH, HV_BINOP_MULTIPLY, 1, m, &cBinop_5Gw5yqSH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_KGm2VA63_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vOKI8Xiz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_uzkaHJOp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qZyIb2cV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_PZqOE8ZQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_L1bzTGLw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_AXUsaVsv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_SKUl5GxE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_pCxiQySz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_FXNz7HYd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_7W8PPKSr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_JMwkDbWl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_C9JJ9gx0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_A9gjEfMR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_Gkn9w7t4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Me8XRQJx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_l2sEnBy6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NfOix0kq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_usQFMyUn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Pgqfw07d_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Pgqfw07d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PovzMPFU, HV_BINOP_MULTIPLY, 1, m, &cBinop_PovzMPFU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PovzMPFU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_zFT98TfZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zFT98TfZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_l2sEnBy6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_vOKI8Xiz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ucIwIrBQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ucIwIrBQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0ikzIFaM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ERNTF2Sb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0ihielLS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Lw1qvhg5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4YONC6Ct_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SQ1NBolC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2yQtAL5P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FvbZqGm5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_5dFVdY61_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BZfQ7olH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_d2nUouNT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_onpJazTo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_2JPJfJKR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WHV92ohc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_5Gw5yqSH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xDraMB6N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_wZxFi3PN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uzkaHJOp, 0, m, &cVar_uzkaHJOp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_8jpdm20u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AXUsaVsv, 1, m, &cVar_AXUsaVsv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_SQ1NBolC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2yQtAL5P, HV_BINOP_MULTIPLY, 0, m, &cBinop_2yQtAL5P_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_0ihielLS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2JPJfJKR, HV_BINOP_MULTIPLY, 0, m, &cBinop_2JPJfJKR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_4YONC6Ct_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5dFVdY61, HV_BINOP_MULTIPLY, 0, m, &cBinop_5dFVdY61_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ERNTF2Sb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5Gw5yqSH, HV_BINOP_MULTIPLY, 0, m, &cBinop_5Gw5yqSH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Lw1qvhg5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_d2nUouNT, HV_BINOP_MULTIPLY, 0, m, &cBinop_d2nUouNT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_0ikzIFaM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_L1bzTGLw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KGm2VA63, 0, m, &cVar_KGm2VA63_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_qZyIb2cV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AXUsaVsv, 0, m, &cVar_AXUsaVsv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NjKgVIir_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rvXf6ZS5, 1, m, &cIf_rvXf6ZS5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_4ki8CETH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_eq5j0DXF, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Vp2E3sPq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4ki8CETH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_x9taUAGP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rvXf6ZS5, 0, m, &cIf_rvXf6ZS5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_W3BKb8uz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Je7sTOEi, HV_BINOP_DIVIDE, 0, m, &cBinop_Je7sTOEi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_u4qVfOwf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_I5hCXIwy, HV_BINOP_DIVIDE, 1, m, &cBinop_I5hCXIwy_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Je7sTOEi, HV_BINOP_DIVIDE, 1, m, &cBinop_Je7sTOEi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_0NGIihJ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Tst1gHC9, HV_BINOP_DIVIDE, 0, m, &cBinop_Tst1gHC9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_Hof7B0GM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Tst1gHC9, HV_BINOP_DIVIDE, 1, m, &cBinop_Tst1gHC9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_1nuVi8O8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_I5hCXIwy, HV_BINOP_DIVIDE, 0, m, &cBinop_I5hCXIwy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_j4qjop8i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_W3BKb8uz, 0, m, &cVar_W3BKb8uz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_KZ2HUhy7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_u4qVfOwf, 0, m, &cVar_u4qVfOwf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_I5hCXIwy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_0NGIihJ8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Je7sTOEi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_Hof7B0GM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Tst1gHC9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_AJtP4S6K_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_7xOmoN4s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_yDAlTmjA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7PhGdYMj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_cv9h93l4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_AJtP4S6K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_7PhGdYMj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cv9h93l4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_7xOmoN4s_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yDAlTmjA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wGVYVL1i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_3H45LZgG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8v7dx1SN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_OceFT3pO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f0sjK95s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_SEU4j2ap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mUut1usw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_Kz5hAdSJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_l4FT90fZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_ITs6T9pu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pCNyYcPG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_Hk2G3AlN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WXjPKVBD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_TVB2okV1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bwO2SBMu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_4VgTOIDL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DkUhNlQV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_WW28TwDG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_C84BFTV7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_3O0KiQT8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_abqqCvlj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_vj3eaO0U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LAuODebp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_KyAPJ2t3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CBa63mPb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_UpM6jlZq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_VEGKpJjq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VEGKpJjq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_t5PLyRQh, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_YXrdzSfP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_1yaBzRHC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_1yaBzRHC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_MGFUg0FH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_6mo1Axmw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tWCBFtbZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_sm6kwdvi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_hIoE20nk_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_W1bpn2ag, m);
}

void Heavy_WSTD_FL3NGR::cBinop_MGFUg0FH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_oRdFBhFK, m);
}

void Heavy_WSTD_FL3NGR::cMsg_tWCBFtbZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_sm6kwdvi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_hIoE20nk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_OSiwjeOb, m);
}

void Heavy_WSTD_FL3NGR::cMsg_52XuRBJS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_KDmV041W_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_KDmV041W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_mQlzF8OE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_bvTC7SML_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jag9p3R9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_DeOH1M2Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_rp8VlgJ5_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_emXxiq7h, m);
}

void Heavy_WSTD_FL3NGR::cBinop_mQlzF8OE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_PTHoH5GW, m);
}

void Heavy_WSTD_FL3NGR::cMsg_jag9p3R9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_DeOH1M2Q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rp8VlgJ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_diFkhrzT, m);
}

void Heavy_WSTD_FL3NGR::cBinop_qAAFiHmP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_6bcuTwkx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6bcuTwkx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_gUxPpTRA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_ZGEEJ0Jo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RU2gFpx4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_DM9oZMWW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CgSNMY5y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_gUxPpTRA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Y25iSFuh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Y25iSFuh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wWEUL3IK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4qt8Hh4P_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_4qt8Hh4P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Fuz3mHKs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_wWEUL3IK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_70h8NtHC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_70h8NtHC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_9xo73lpP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Fuz3mHKs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_xTJ9WsMu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xTJ9WsMu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_2s3tYlHW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9xo73lpP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_ZGEEJ0Jo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2s3tYlHW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_DM9oZMWW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_I0wrTwH9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_qXgCerXV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qXgCerXV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YpRSXKOc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_66W6ibSG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_FVCDvYSa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_FVCDvYSa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_gvEFvTtS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_DseSYvFC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_DseSYvFC, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ij4YxkeB, 0, m, &cDelay_Ij4YxkeB_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DseSYvFC, 0, m, &cDelay_DseSYvFC_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_1ZvKaPRr, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_Ij4YxkeB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Ij4YxkeB, m);
  cMsg_RW0ChlFd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_72RrJpuU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_fVHlNUFA_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_7QnR950I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_n5S9CkI6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_ugBSGtxz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TPIvQr48_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DseSYvFC, 2, m, &cDelay_DseSYvFC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SBWGOwVS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_n5S9CkI6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_ugBSGtxz, 0, m, &hTable_ugBSGtxz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gvEFvTtS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_7QnR950I_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_RW0ChlFd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_ugBSGtxz, 0, m, &hTable_ugBSGtxz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_SBWGOwVS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_DseSYvFC, 0, m, &cDelay_DseSYvFC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_TPIvQr48_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ij4YxkeB, 2, m, &cDelay_Ij4YxkeB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_fVHlNUFA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_1ZvKaPRr, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_Kv3fmThf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_s0xAxMip_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_s0xAxMip_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_bvVJMN8z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_UCp5jRQp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UCp5jRQp, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_cczfQvs6, 0, m, &cDelay_cczfQvs6_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_UCp5jRQp, 0, m, &cDelay_UCp5jRQp_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_QU0jAle7, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_cczfQvs6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_cczfQvs6, m);
  cMsg_oIFU8Jty_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_2Q49t1YZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_LYsUeqhJ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_fnvKkpHM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JrrFB7wg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_g9CiPUI0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OZKGPfRy_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_UCp5jRQp, 2, m, &cDelay_UCp5jRQp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ReQIIxFu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_JrrFB7wg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_g9CiPUI0, 0, m, &hTable_g9CiPUI0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bvVJMN8z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_fnvKkpHM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_oIFU8Jty_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_g9CiPUI0, 0, m, &hTable_g9CiPUI0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ReQIIxFu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_UCp5jRQp, 0, m, &cDelay_UCp5jRQp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_OZKGPfRy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_cczfQvs6, 2, m, &cDelay_cczfQvs6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_LYsUeqhJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_QU0jAle7, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_ohB1HmBR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QBWRwCJO, HV_BINOP_MULTIPLY, 0, m, &cBinop_QBWRwCJO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_DhXEWTF3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_zyJIW1El_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_zyJIW1El_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_io8oE2dr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_QBWRwCJO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_XjD7cr2C_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ekJL33Fe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QBWRwCJO, HV_BINOP_MULTIPLY, 1, m, &cBinop_QBWRwCJO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_io8oE2dr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ekJL33Fe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XjD7cr2C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Q0EwiOl7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Q0EwiOl7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_J6hwaeSs_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_DonbzVrf, m);
}

void Heavy_WSTD_FL3NGR::cBinop_J6hwaeSs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_DEAaBuJe, m);
}

void Heavy_WSTD_FL3NGR::cVar_KSRqOgiI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fX0iivpn, HV_BINOP_MULTIPLY, 0, m, &cBinop_fX0iivpn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_MtRgsvQn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_SEhAeAa2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_SEhAeAa2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZOsqVLu5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_fX0iivpn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_zNDFNEVr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TC00ZFBY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fX0iivpn, HV_BINOP_MULTIPLY, 1, m, &cBinop_fX0iivpn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ZOsqVLu5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_TC00ZFBY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zNDFNEVr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_lSvK710P_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lSvK710P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Cyw3QyBW_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_cCeOUQrS, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Cyw3QyBW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_rGOWihpy, m);
}

void Heavy_WSTD_FL3NGR::cMsg_YpRSXKOc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZB03CxYH, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_ZuZW5M6U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_UkWvAEg6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_hcl0bTWz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_NyyZzIZz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_cCDUxj2D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_ZuZW5M6U_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_753vklke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_HX5mwzSY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HX5mwzSY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_exRFuGf1, HV_BINOP_MULTIPLY, 1, m, &cBinop_exRFuGf1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NyyZzIZz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_753vklke_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_exRFuGf1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IKUVUGdZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_UkWvAEg6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_exRFuGf1, HV_BINOP_MULTIPLY, 0, m, &cBinop_exRFuGf1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_IKUVUGdZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_p3YWPFTc, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_ffeqSr3b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_H1XR8pen_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_H1XR8pen_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hcl0bTWz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cCDUxj2D_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_iAZ7QZIG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_P8BxNnOj, 0, m, &cSlice_P8BxNnOj_sendMessage);
      break;
    }
    default: {
      cSwitchcase_j8uW14gh_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_P8BxNnOj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_pJyIFG5w_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_pJyIFG5w_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_iKqe2wg8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pJyIFG5w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_pJyIFG5w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LMCR8fPO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_j8uW14gh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_w5Ry0Ew0, 0, m, &cSlice_w5Ry0Ew0_sendMessage);
      break;
    }
    default: {
      cSwitchcase_UkOsiIH3_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_w5Ry0Ew0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_aSYrbzee_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_aSYrbzee_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_MWqu7Zec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_aSYrbzee_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_aSYrbzee_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_N0H3zxiS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_UkOsiIH3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_b4fYygAl, 0, m, &cSlice_b4fYygAl_sendMessage);
      break;
    }
    default: {
      cSwitchcase_capWlXeB_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_b4fYygAl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_apzKCuRM_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_apzKCuRM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_p5X2YWeN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_apzKCuRM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_apzKCuRM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_48TMzmCA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_capWlXeB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_FEM2Hz2r, 0, m, &cSlice_FEM2Hz2r_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_FEM2Hz2r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_TdhXjsPu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_TdhXjsPu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_Hi7zlKLa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_TdhXjsPu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_TdhXjsPu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_kRvPqAri_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_RU2gFpx4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qLZT2gtM, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_CgSNMY5y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZQ1yPd0l, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_7ruQdW95_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_FByGfwju_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FByGfwju_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_MFfnDIXH, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_51yfpq8n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Oldvmaj7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_Oldvmaj7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_zO2an0Ph_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_bxWMrwdF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TYHOt7Nj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_oXkWM0Lv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_qK1ItuRb_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_JMEunFMf, m);
}

void Heavy_WSTD_FL3NGR::cBinop_zO2an0Ph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_TfwLsmb1, m);
}

void Heavy_WSTD_FL3NGR::cMsg_TYHOt7Nj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_oXkWM0Lv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qK1ItuRb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_9AYK4ryW, m);
}

void Heavy_WSTD_FL3NGR::cMsg_WFkorYMz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_v2dgVUzY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_v2dgVUzY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_RgyiMvYy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_Td0UU3e0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bopL6cza_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_fBltP3XI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_gz1OBiK8_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_6KJEPjWl, m);
}

void Heavy_WSTD_FL3NGR::cBinop_RgyiMvYy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_yBhnDiMj, m);
}

void Heavy_WSTD_FL3NGR::cMsg_bopL6cza_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fBltP3XI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gz1OBiK8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_HZ1FVPwN, m);
}

void Heavy_WSTD_FL3NGR::cBinop_VRcj4Pm5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_aBxXjgQ3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_aBxXjgQ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_EdIuOJIy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_nl2PSHlt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Qsq5QmVW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_x3XzMzAm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DI2CcJh7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_EdIuOJIy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_CiGkeKsK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CiGkeKsK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kO64J9qh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HPFTMsRk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_HPFTMsRk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DDHW3alB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_kO64J9qh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_j5N5VfsW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_j5N5VfsW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_p9SShVOE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_DDHW3alB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_4AAK4qbW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4AAK4qbW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_5yfnc7Y4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_p9SShVOE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_nl2PSHlt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5yfnc7Y4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_x3XzMzAm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_jbSHrkoa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_q9vzBfMp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_q9vzBfMp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FJ80T7uj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_7mi8TAFb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Fz3llpNC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_Fz3llpNC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_49f3byay_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_Ad5wauPi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Ad5wauPi, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_OF5SqfHp, 0, m, &cDelay_OF5SqfHp_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ad5wauPi, 0, m, &cDelay_Ad5wauPi_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_7S872WnF, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_OF5SqfHp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_OF5SqfHp, m);
  cMsg_NF9NtHWq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_MpdmynAf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_GWNWXq02_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_59wvKQAz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CnyXeRXg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_6z2NtUSM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_i7ti1hRz_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ad5wauPi, 2, m, &cDelay_Ad5wauPi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8KfmXIYP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_CnyXeRXg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_6z2NtUSM, 0, m, &hTable_6z2NtUSM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_49f3byay_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_59wvKQAz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_NF9NtHWq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_6z2NtUSM, 0, m, &hTable_6z2NtUSM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_8KfmXIYP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ad5wauPi, 0, m, &cDelay_Ad5wauPi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_i7ti1hRz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_OF5SqfHp, 2, m, &cDelay_OF5SqfHp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_GWNWXq02_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_7S872WnF, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_s885wopg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_EMJiK7on_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_EMJiK7on_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_I73XtTM2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_IZCbdcmS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_IZCbdcmS, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_lTJhNZyo, 0, m, &cDelay_lTJhNZyo_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_IZCbdcmS, 0, m, &cDelay_IZCbdcmS_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_BpMsIEFE, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_lTJhNZyo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_lTJhNZyo, m);
  cMsg_m6eV7qLL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_Rp3Vqe5N_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_UNtD8TYd_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_XDItftCB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zq4Ql2DZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_OclzoPJK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZRz25gb6_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_IZCbdcmS, 2, m, &cDelay_IZCbdcmS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R5gLiyJi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_zq4Ql2DZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_OclzoPJK, 0, m, &hTable_OclzoPJK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_I73XtTM2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_XDItftCB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_m6eV7qLL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_OclzoPJK, 0, m, &hTable_OclzoPJK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_R5gLiyJi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_IZCbdcmS, 0, m, &cDelay_IZCbdcmS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ZRz25gb6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_lTJhNZyo, 2, m, &cDelay_lTJhNZyo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_UNtD8TYd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_BpMsIEFE, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_9Eb3tmuD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KstrMhDT, HV_BINOP_MULTIPLY, 0, m, &cBinop_KstrMhDT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_osfI3vYD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ZzIInTil_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_ZzIInTil_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4ot2Suf0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_KstrMhDT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_c73K5TK2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZjnydPRj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KstrMhDT, HV_BINOP_MULTIPLY, 1, m, &cBinop_KstrMhDT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_4ot2Suf0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ZjnydPRj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_c73K5TK2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_iRJV6Vl1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_iRJV6Vl1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_vZQqcQ2Q_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_5oi11rA2, m);
}

void Heavy_WSTD_FL3NGR::cBinop_vZQqcQ2Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Zusswma0, m);
}

void Heavy_WSTD_FL3NGR::cVar_IwQWT02t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_I3EqtalF, HV_BINOP_MULTIPLY, 0, m, &cBinop_I3EqtalF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_vvLpUdqp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_EdLlH2v1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_EdLlH2v1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fkwDooSW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_I3EqtalF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_kN4y3m1C_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_MkcDm7Df_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_I3EqtalF, HV_BINOP_MULTIPLY, 1, m, &cBinop_I3EqtalF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_fkwDooSW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_MkcDm7Df_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_kN4y3m1C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_fr1DiAjK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fr1DiAjK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_MQAKAGwk_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_QX53fJp6, m);
}

void Heavy_WSTD_FL3NGR::cBinop_MQAKAGwk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_pcEgFWtP, m);
}

void Heavy_WSTD_FL3NGR::cMsg_FJ80T7uj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UzMx3SW2, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_Sz4WsrcQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_dWRiwr3l_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ZrRJ8TpA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_0vs71Hy5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_gynIFS5S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_Sz4WsrcQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KyxUykjM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_BcJqZdGn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BcJqZdGn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LFYrGjlh, HV_BINOP_MULTIPLY, 1, m, &cBinop_LFYrGjlh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0vs71Hy5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_KyxUykjM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_LFYrGjlh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4XjHxvEy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_dWRiwr3l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LFYrGjlh, HV_BINOP_MULTIPLY, 0, m, &cBinop_LFYrGjlh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_4XjHxvEy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oL7M6Xm2, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_hIYaEG2n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_5I0KILcH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5I0KILcH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZrRJ8TpA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gynIFS5S_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_pH3NnM4g_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_WM6o3Hsa, 0, m, &cSlice_WM6o3Hsa_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ZW6y2JYe_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_WM6o3Hsa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_rfegAUWa_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_rfegAUWa_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_lHXpqZ8S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rfegAUWa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_rfegAUWa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_t0HJbXBo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_ZW6y2JYe_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_yayMp0xM, 0, m, &cSlice_yayMp0xM_sendMessage);
      break;
    }
    default: {
      cSwitchcase_vmLe9hvw_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_yayMp0xM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_rWsWH5an_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_rWsWH5an_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_7Qn7u7Tm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rWsWH5an_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_rWsWH5an_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DchdlGoO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_vmLe9hvw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_pShmClXm, 0, m, &cSlice_pShmClXm_sendMessage);
      break;
    }
    default: {
      cSwitchcase_39l6yK6p_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_pShmClXm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_mFlYAvaG_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_mFlYAvaG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_sLTXbIQu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mFlYAvaG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_mFlYAvaG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_i9A332Oy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_39l6yK6p_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_IkXK1ekb, 0, m, &cSlice_IkXK1ekb_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_IkXK1ekb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ULM6hQNS_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ULM6hQNS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_X1cRXdT8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ULM6hQNS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_ULM6hQNS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_TCcLvAMW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_Qsq5QmVW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nzhXFS5d, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_DI2CcJh7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mZpfgJwN, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_Qpix0Qs7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_s5PLs7lN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_s5PLs7lN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_xR2zUXJ0, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_V2znvQKZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_uSanvu58_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_uSanvu58_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_xo2A2xKB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_n9c8wm9J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5bpG3gkZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_MvVaPn94_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_mYTR8xOO_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Bi2SnjfS, m);
}

void Heavy_WSTD_FL3NGR::cBinop_xo2A2xKB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_tvFyZ1ua, m);
}

void Heavy_WSTD_FL3NGR::cMsg_5bpG3gkZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_MvVaPn94_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mYTR8xOO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_bHHbWflu, m);
}

void Heavy_WSTD_FL3NGR::cMsg_WeS3EN8N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_XMfiiHL2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_XMfiiHL2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_huuVp2D7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_BbUqUgB3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2kSzAEMP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_uyEMEDs7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_UcwkQBVn_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_rnD4csW9, m);
}

void Heavy_WSTD_FL3NGR::cBinop_huuVp2D7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_9L9OUyIT, m);
}

void Heavy_WSTD_FL3NGR::cMsg_2kSzAEMP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_uyEMEDs7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_UcwkQBVn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Df7J1ILx, m);
}

void Heavy_WSTD_FL3NGR::cBinop_rh2gl2XA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Te7kg6u8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Te7kg6u8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_2sdpiqhl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_8DXxIFtL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1RtnUSq2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_fEY5YOTq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_E1iOZiPF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_2sdpiqhl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_19ZabbuL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_19ZabbuL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_l1paY5rb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qv15mG76_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_l1paY5rb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_d6DcKmYT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_qv15mG76_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_E9EP8vEJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_d6DcKmYT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Qcr93mz1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_E9EP8vEJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_fRjtN2nj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fRjtN2nj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_nOUpGFi1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Qcr93mz1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_8DXxIFtL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_nOUpGFi1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_fEY5YOTq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qCsS5E9G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_dX9fYbBk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dX9fYbBk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_v1AEEahe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_VSLiT9Rj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_60rOki9a_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_60rOki9a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_qhvvELbP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_IDv03TVB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_IDv03TVB, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Yav6vgpq, 0, m, &cDelay_Yav6vgpq_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_IDv03TVB, 0, m, &cDelay_IDv03TVB_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_KDBXC4TL, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_Yav6vgpq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Yav6vgpq, m);
  cMsg_Up7LGdhi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_xliltwHz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_p6roKYQO_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_TaUKY7uF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_L07qo0fr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_PJYILIsE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5BzhD9dm_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_IDv03TVB, 2, m, &cDelay_IDv03TVB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Fsmu99KH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_L07qo0fr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_PJYILIsE, 0, m, &hTable_PJYILIsE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qhvvELbP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_TaUKY7uF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Up7LGdhi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_PJYILIsE, 0, m, &hTable_PJYILIsE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Fsmu99KH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_IDv03TVB, 0, m, &cDelay_IDv03TVB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_5BzhD9dm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_Yav6vgpq, 2, m, &cDelay_Yav6vgpq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_p6roKYQO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_KDBXC4TL, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_A48mkt20_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_kt7A40y7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_kt7A40y7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_af5zkT0H_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_gSIFzkNd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_gSIFzkNd, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_4gzxLjOQ, 0, m, &cDelay_4gzxLjOQ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_gSIFzkNd, 0, m, &cDelay_gSIFzkNd_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_dqPiu7M0, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_4gzxLjOQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4gzxLjOQ, m);
  cMsg_PzPw9qXv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_RazwUJe0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_bn5KjNsU_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_SJoBmK0J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jQUWucQw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_GNIhoEIA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xzqdVXRi_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_gSIFzkNd, 2, m, &cDelay_gSIFzkNd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ynNKv9nt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_jQUWucQw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_GNIhoEIA, 0, m, &hTable_GNIhoEIA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_af5zkT0H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_SJoBmK0J_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_PzPw9qXv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_GNIhoEIA, 0, m, &hTable_GNIhoEIA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ynNKv9nt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_gSIFzkNd, 0, m, &cDelay_gSIFzkNd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_xzqdVXRi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_4gzxLjOQ, 2, m, &cDelay_4gzxLjOQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_bn5KjNsU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_dqPiu7M0, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_fsObeTET_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PNDlZ0Cg, HV_BINOP_MULTIPLY, 0, m, &cBinop_PNDlZ0Cg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_afJwYG8d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_yOiYzLms_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_yOiYzLms_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vPHW4B1X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_PNDlZ0Cg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_M50kSgXM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_IKXm88ic_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PNDlZ0Cg, HV_BINOP_MULTIPLY, 1, m, &cBinop_PNDlZ0Cg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_vPHW4B1X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_IKXm88ic_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_M50kSgXM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_saR97ts2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_saR97ts2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_xLxrUxa6_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_oxHaTdLu, m);
}

void Heavy_WSTD_FL3NGR::cBinop_xLxrUxa6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_fctQKI10, m);
}

void Heavy_WSTD_FL3NGR::cVar_MAAFHkxp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FQI4EkuL, HV_BINOP_MULTIPLY, 0, m, &cBinop_FQI4EkuL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_KABAHDnu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7hVJzhsx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_7hVJzhsx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fIoAtzWD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_FQI4EkuL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_8d8wkUA5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_eikFzTt6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FQI4EkuL, HV_BINOP_MULTIPLY, 1, m, &cBinop_FQI4EkuL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_fIoAtzWD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_eikFzTt6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8d8wkUA5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_i3qzt6XW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_i3qzt6XW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_9rULUknW_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_mi8KmQGX, m);
}

void Heavy_WSTD_FL3NGR::cBinop_9rULUknW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Yj8RlYNe, m);
}

void Heavy_WSTD_FL3NGR::cMsg_v1AEEahe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_du0DsJXK, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_5sFAYbd4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_kg5tbpGq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_7I7eyZsG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_5sFAYbd4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_2Fv8H9a1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ScLLCvja_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_JyECJJbC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_w7sF1THs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_w7sF1THs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_I1M3vOrf, HV_BINOP_MULTIPLY, 1, m, &cBinop_I1M3vOrf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ScLLCvja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_JyECJJbC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_I1M3vOrf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CIlBRbTb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_kg5tbpGq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_I1M3vOrf, HV_BINOP_MULTIPLY, 0, m, &cBinop_I1M3vOrf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_CIlBRbTb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KVnkE6T3, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_XCGAZ1XU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_kdNSRk4O_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_kdNSRk4O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2Fv8H9a1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7I7eyZsG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_3ybcjeQu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_MCjqXPd0, 0, m, &cSlice_MCjqXPd0_sendMessage);
      break;
    }
    default: {
      cSwitchcase_7CwmYzIe_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_MCjqXPd0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_f1CrebSG_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_f1CrebSG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_b4Nm62TN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_f1CrebSG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_f1CrebSG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2CwXRMKj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_7CwmYzIe_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_3y39WiZh, 0, m, &cSlice_3y39WiZh_sendMessage);
      break;
    }
    default: {
      cSwitchcase_JOGfWr7Q_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_3y39WiZh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_trNxXdCv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_trNxXdCv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_Y0GB0avi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_trNxXdCv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_trNxXdCv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NrhDtSrB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_JOGfWr7Q_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ixOfrpiC, 0, m, &cSlice_ixOfrpiC_sendMessage);
      break;
    }
    default: {
      cSwitchcase_EkopzIWB_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_ixOfrpiC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_OQYQ9wHY_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_OQYQ9wHY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_wIlU3KAM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_OQYQ9wHY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_OQYQ9wHY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0TQy762j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_EkopzIWB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_y51Q6zje, 0, m, &cSlice_y51Q6zje_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_y51Q6zje_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_v4fSIRks_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_v4fSIRks_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_oESQo6KC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_v4fSIRks_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_v4fSIRks_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1Jv2ckr7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_1RtnUSq2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ywzdwClY, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_E1iOZiPF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vTZQqP6D, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_bQyOhodk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_GtLkLhwI_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_7qtxaFG0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_o2D0IOsF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_GtLkLhwI_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_7qtxaFG0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_p5hqXWCD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_GtLkLhwI_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_7qtxaFG0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_piXqjs8L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_GtLkLhwI_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_7qtxaFG0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_wGVYVL1i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_GtLkLhwI_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_7qtxaFG0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_GMt3GMWY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_27tAIEXJ, 0, m, &cVar_27tAIEXJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_tYEoHFIs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_kyIz4kXB, 0, m, &cVar_kyIz4kXB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_bV0ALgs9, 0, m, &cVar_bV0ALgs9_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_DFir1q6w, 0, m, &cVar_DFir1q6w_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_l4FT90fZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_iAZ7QZIG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_8v7dx1SN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_iAZ7QZIG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_f0sjK95s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_iAZ7QZIG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_mUut1usw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_iAZ7QZIG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_mSpfu1Fb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Kz5hAdSJ, 0, m, &cVar_Kz5hAdSJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CjPLPc5a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3H45LZgG, 0, m, &cVar_3H45LZgG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ts75jSaD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SEU4j2ap, 0, m, &cVar_SEU4j2ap_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_DkUhNlQV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_pH3NnM4g_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_pCNyYcPG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_pH3NnM4g_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_WXjPKVBD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_pH3NnM4g_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_bwO2SBMu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_pH3NnM4g_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_NcbPXwuz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4VgTOIDL, 0, m, &cVar_4VgTOIDL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_hhrxYiWt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ITs6T9pu, 0, m, &cVar_ITs6T9pu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WY8AmSRe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TVB2okV1, 0, m, &cVar_TVB2okV1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_CBa63mPb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_3ybcjeQu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_C84BFTV7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_3ybcjeQu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_abqqCvlj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_3ybcjeQu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_LAuODebp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_3ybcjeQu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_i6at0Yj5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KyAPJ2t3, 0, m, &cVar_KyAPJ2t3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XXyqWRk9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WW28TwDG, 0, m, &cVar_WW28TwDG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_k3ZzZJSn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vj3eaO0U, 0, m, &cVar_vj3eaO0U_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Z86XltcP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kyIz4kXB, 0, m, &cVar_kyIz4kXB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_BNSvuuy6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bV0ALgs9, 0, m, &cVar_bV0ALgs9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_0KegT8Ac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DFir1q6w, 0, m, &cVar_DFir1q6w_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_pFe6T14Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pg8KPQfj, 0, m, &cVar_pg8KPQfj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_tmnyX3XW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_E58lgcHD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ohjOIWAZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_0LUeZyQb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ajijiRTn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_abJrij89_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yPjkg6ya_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_GAY1b0Bt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6QydghA0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PG2fEH8i_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xfzgdn3W_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_wBqv8Ou7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_f5bunBO9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OtVrfREO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qGQfzsHF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_K6bO5Kha_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mQQZxJLU_sendMessage(_c, 0, m);
  cMsg_xD8bYRol_sendMessage(_c, 0, m);
  cMsg_0YKuZV51_sendMessage(_c, 0, m);
  cMsg_iWUwEiP1_sendMessage(_c, 0, m);
  cMsg_IaFLwMq4_sendMessage(_c, 0, m);
  cMsg_HJv509gC_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_vJzLuHij, 0, m, &cVar_vJzLuHij_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_pg8KPQfj, 0, m, &cVar_pg8KPQfj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MaQQSZWn, 0, m, &cVar_MaQQSZWn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_njdIrW7j, 0, m, &cVar_njdIrW7j_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jdKsWt58, 0, m, &cVar_jdKsWt58_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_uzkaHJOp, 0, m, &cVar_uzkaHJOp_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9jXwFnbb, 0, m, &cVar_9jXwFnbb_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xtgz3lw3, 0, m, &cVar_xtgz3lw3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PyVGAy3t, 0, m, &cVar_PyVGAy3t_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8LVHlTis, 0, m, &cVar_8LVHlTis_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_E4sIX6uI, 0, m, &cVar_E4sIX6uI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YPbLKPzE, 0, m, &cVar_YPbLKPzE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_IgyCuGKC, 0, m, &cVar_IgyCuGKC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_a9yTzArx, 0, m, &cVar_a9yTzArx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GzeUIWbB, 0, m, &cVar_GzeUIWbB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WtRAwYBO, 0, m, &cVar_WtRAwYBO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_UQfqt1ez, 0, m, &cVar_UQfqt1ez_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KQnU6oAw, 0, m, &cVar_KQnU6oAw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_oiHyJx6A, 0, m, &cVar_oiHyJx6A_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_gYSnhorf, 0, m, &cVar_gYSnhorf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_UlbVWQvj, 0, m, &cVar_UlbVWQvj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vkD0wuso, 0, m, &cVar_vkD0wuso_sendMessage);
  cMsg_DhXEWTF3_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ohB1HmBR, 0, m, &cVar_ohB1HmBR_sendMessage);
  cMsg_MtRgsvQn_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_KSRqOgiI, 0, m, &cVar_KSRqOgiI_sendMessage);
  cMsg_osfI3vYD_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_9Eb3tmuD, 0, m, &cVar_9Eb3tmuD_sendMessage);
  cMsg_vvLpUdqp_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_IwQWT02t, 0, m, &cVar_IwQWT02t_sendMessage);
  cMsg_afJwYG8d_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_fsObeTET, 0, m, &cVar_fsObeTET_sendMessage);
  cMsg_KABAHDnu_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_MAAFHkxp, 0, m, &cVar_MAAFHkxp_sendMessage);
  cMsg_66W6ibSG_sendMessage(_c, 0, m);
  cMsg_Kv3fmThf_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_iKqe2wg8, 0, m, &cVar_iKqe2wg8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MWqu7Zec, 0, m, &cVar_MWqu7Zec_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_p5X2YWeN, 0, m, &cVar_p5X2YWeN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Hi7zlKLa, 0, m, &cVar_Hi7zlKLa_sendMessage);
  cMsg_7mi8TAFb_sendMessage(_c, 0, m);
  cMsg_s885wopg_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_lHXpqZ8S, 0, m, &cVar_lHXpqZ8S_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7Qn7u7Tm, 0, m, &cVar_7Qn7u7Tm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sLTXbIQu, 0, m, &cVar_sLTXbIQu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_X1cRXdT8, 0, m, &cVar_X1cRXdT8_sendMessage);
  cMsg_VSLiT9Rj_sendMessage(_c, 0, m);
  cMsg_A48mkt20_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_b4Nm62TN, 0, m, &cVar_b4Nm62TN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Y0GB0avi, 0, m, &cVar_Y0GB0avi_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wIlU3KAM, 0, m, &cVar_wIlU3KAM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_oESQo6KC, 0, m, &cVar_oESQo6KC_sendMessage);
  cMsg_tYEoHFIs_sendMessage(_c, 0, m);
  cMsg_GMt3GMWY_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_6mo1Axmw, 0, m, &cVar_6mo1Axmw_sendMessage);
  cMsg_YXrdzSfP_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_bvTC7SML, 0, m, &cVar_bvTC7SML_sendMessage);
  cMsg_52XuRBJS_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_bxWMrwdF, 0, m, &cVar_bxWMrwdF_sendMessage);
  cMsg_51yfpq8n_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Td0UU3e0, 0, m, &cVar_Td0UU3e0_sendMessage);
  cMsg_WFkorYMz_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_n9c8wm9J, 0, m, &cVar_n9c8wm9J_sendMessage);
  cMsg_V2znvQKZ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_BbUqUgB3, 0, m, &cVar_BbUqUgB3_sendMessage);
  cMsg_WeS3EN8N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_7Isw8L87_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_40imlosr, HV_BINOP_MULTIPLY, 0, m, &cBinop_40imlosr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_o83bQATY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_TZkxMGLe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_S8mCJubj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_yku4Mtjj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_WX4fAEWt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_HzJhi2ne_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_dStjhzII_sendMessage);
  cMsg_amCohVK2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_zLTiDhWk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZksDLrDq, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZksDLrDq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_lCFJjZVP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_fz6QRSop_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_sle1xufc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oDKf9Q5z, HV_BINOP_MULTIPLY, 1, m, &cBinop_oDKf9Q5z_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_sW4I1pcw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_UMj0CvFD_sendMessage);
  cMsg_c2BZdrFE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_u71Z8cMR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PmjG30eZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_PmjG30eZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_0Dn9eBqH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_REneCejQ_sendMessage(_c, 0, m);
  cMsg_0mhG2PMo_sendMessage(_c, 0, m);
  cMsg_k1aTiLKX_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_y2XFJUst_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_m8NdkCPq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_k5CZjske_sendMessage);
  cMsg_N5oeu0KN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_boCtf4m1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jdKsWt58, 0, m, &cVar_jdKsWt58_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_rGnWJwbk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lfcD4SkC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Idtpm9DY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_bJ1fkOey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_L5VUM8on_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MQUM4tsT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uwoPhCRp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_nvv1XGiA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_D4gyoUkk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JoPodbR0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ciYNe0FJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_cibF9YNj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BBb62GPd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lchXMnT7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jjzR0LBs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_h3MXS9q4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z8a9pmxQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_Z8a9pmxQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_qRD9OFOm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_gNEN1193_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_AcIniHJV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_YFDOoocC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_ras3Ysgw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_HXgLSvqP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_WRV4QElB_sendMessage);
  cMsg_cWpB0Lpk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_bgFhsBOw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EvuojrHh, HV_BINOP_MULTIPLY, 0, m, &cBinop_EvuojrHh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_xYV7alA4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_x8OHKFvC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_oqgybTl0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mFRVKTdQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_mFRVKTdQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_XaVJZQF6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_bqTar5Pg_sendMessage);
  cMsg_MgwFaBBO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_A9gjEfMR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PovzMPFU, HV_BINOP_MULTIPLY, 0, m, &cBinop_PovzMPFU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Me8XRQJx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nqx9Qr00_sendMessage(_c, 0, m);
  cMsg_tYyRD681_sendMessage(_c, 0, m);
  cMsg_3cnVvdgM_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_9msTS3hE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_NfOix0kq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_9GIsLuav_sendMessage);
  cMsg_s0VoMFib_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_eFCuS7K0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_27tAIEXJ, 0, m, &cVar_27tAIEXJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_zixlxj8M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_mSpfu1Fb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_vu8wINB8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_CjPLPc5a_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_6DFuaBa7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OceFT3pO, 0, m, &cVar_OceFT3pO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_vd1XyD8s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_ts75jSaD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_xCzqQyiK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_NcbPXwuz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_unUCiQo8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_hhrxYiWt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Go0yT90z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Hk2G3AlN, 0, m, &cVar_Hk2G3AlN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_kEePgpOQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_WY8AmSRe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_xXAhHCw9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_i6at0Yj5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_7d9HcMc8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_XXyqWRk9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_wTjRZUTJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3O0KiQT8, 0, m, &cVar_3O0KiQT8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_uWBxNaUV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_k3ZzZJSn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_48TMzmCA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_UpM6jlZq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_N0H3zxiS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ffeqSr3b_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_kRvPqAri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_qAAFiHmP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_LMCR8fPO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_I0wrTwH9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_i9A332Oy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_7ruQdW95_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_DchdlGoO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_hIYaEG2n_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_TCcLvAMW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_VRcj4Pm5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_t0HJbXBo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_jbSHrkoa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_0TQy762j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_Qpix0Qs7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_NrhDtSrB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_XCGAZ1XU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_1Jv2ckr7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_rh2gl2XA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_2CwXRMKj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_qCsS5E9G_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_FL3NGR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_L9LOYhNx, VOf(Bf0));
    __hv_line_f(&sLine_VO4x8yeb, VOf(Bf1));
    __hv_line_f(&sLine_3mvtgJO8, VOf(Bf2));
    __hv_line_f(&sLine_lVwKnrMZ, VOf(Bf3));
    __hv_line_f(&sLine_wJeue3mA, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_eLcuktGn, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_qCqo5Gvc, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_biSOmqb0, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_kCX9mIRq, VOf(Bf1));
    __hv_line_f(&sLine_TPv0Li4m, VOf(Bf0));
    __hv_line_f(&sLine_9rPNVi0c, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_92xXZZqf, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_cAzZHvSy, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_CULt5gCq, VOf(Bf5));
    __hv_line_f(&sLine_Nh6qBen3, VOf(Bf1));
    __hv_line_f(&sLine_8wMMkJl4, VOf(Bf2));
    __hv_line_f(&sLine_vsvWMAPR, VOf(Bf4));
    __hv_line_f(&sLine_MvQJcrV1, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_NM2tn7WU, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_q6QfuSRd, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_oMMpsgRW, VOf(Bf6));
    __hv_line_f(&sLine_nHA1MKoK, VOf(Bf2));
    __hv_line_f(&sLine_WS07jkZu, VOf(Bf1));
    __hv_line_f(&sLine_AFY8em8B, VOf(Bf5));
    __hv_line_f(&sLine_kIPvVVrh, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_36UDCi5k, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_asFtP1wS, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_ZYFwohQJ, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_k4k9iJ3E, VOf(Bf2));
    __hv_line_f(&sLine_UqCvs45e, VOf(Bf6));
    __hv_line_f(&sLine_8ezbnnkl, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_LXfmEd6w, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_eq5j0DXF, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_uxgUaP1E, VOf(Bf8));
    __hv_line_f(&sLine_geS9R11w, VOf(Bf2));
    __hv_line_f(&sLine_rcW4s83b, VOf(Bf1));
    __hv_line_f(&sLine_3txu3z0o, VOf(Bf7));
    __hv_line_f(&sLine_siPf779k, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_Xe8Vh5CP, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_B8hZEEEN, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_ZQ1yPd0l, VOf(Bf9));
    __hv_phasor_k_f(&sPhasor_t5PLyRQh, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf8), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_ZB03CxYH, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf10), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf2), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf1), VIf(Bf10), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_neg_f(VIf(Bf1), VOf(Bf8));
    __hv_add_f(VIf(Bf8), VIf(Bf10), VOf(Bf8));
    __hv_varread_f(&sVarf_DonbzVrf, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_DEAaBuJe, VOf(Bf8));
    __hv_rpole_f(&sRPole_PEHzEfCH, VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_cCeOUQrS, VOf(Bf1));
    __hv_mul_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_rGOWihpy, VOf(Bf10));
    __hv_rpole_f(&sRPole_3JHzQjyP, VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_tabhead_f(&sTabhead_rtI2IlF8, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf2), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_oRdFBhFK, VOf(Bf1));
    __hv_mul_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_OSiwjeOb, VOf(Bf10));
    __hv_min_f(VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf2));
    __hv_varread_f(&sVarf_W1bpn2ag, VOf(Bf10));
    __hv_zero_f(VOf(Bf11));
    __hv_lt_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_and_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_cast_fi(VIf(Bf11), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_0a1CQn1S, VIi(Bi1), VOf(Bf11));
    __hv_tabread_if(&sTabread_KDX8J2NZ, VIi(Bi0), VOf(Bf10));
    __hv_sub_f(VIf(Bf11), VIf(Bf10), VOf(Bf11));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf11), VIf(Bf2), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_qLZT2gtM, VOf(Bf2));
    __hv_mul_f(VIf(Bf10), VIf(Bf2), VOf(Bf11));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_tabhead_f(&sTabhead_3nm4AZoy, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_PTHoH5GW, VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_diFkhrzT, VOf(Bf8));
    __hv_min_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf12), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf12));
    __hv_varread_f(&sVarf_emXxiq7h, VOf(Bf8));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf8), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_1z7pPDaq, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_Z0Dk50Er, VIi(Bi0), VOf(Bf8));
    __hv_sub_f(VIf(Bf13), VIf(Bf8), VOf(Bf13));
    __hv_sub_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf8), VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf2));
    __hv_fma_f(VIf(Bf9), VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_p3YWPFTc, VOf(Bf9));
    __hv_fma_f(VIf(Bf9), VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_1ZvKaPRr, VIf(Bf5));
    __hv_fma_f(VIf(Bf10), VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_QU0jAle7, VIf(Bf3));
    __hv_varwrite_f(&sVarf_otlHgdcg, VIf(Bf11));
    __hv_line_f(&sLine_mZpfgJwN, VOf(Bf11));
    __hv_phasor_k_f(&sPhasor_MFfnDIXH, VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_abs_f(VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf3), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf9), VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_UzMx3SW2, VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf5), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf3));
    __hv_mul_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_neg_f(VIf(Bf3), VOf(Bf10));
    __hv_add_f(VIf(Bf10), VIf(Bf5), VOf(Bf10));
    __hv_varread_f(&sVarf_5oi11rA2, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_Zusswma0, VOf(Bf10));
    __hv_rpole_f(&sRPole_g1vysm1N, VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_QX53fJp6, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_pcEgFWtP, VOf(Bf5));
    __hv_rpole_f(&sRPole_gW2qYKse, VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_tabhead_f(&sTabhead_sIxz4ZqX, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf9), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_TfwLsmb1, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_9AYK4ryW, VOf(Bf5));
    __hv_min_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf9));
    __hv_varread_f(&sVarf_JMEunFMf, VOf(Bf5));
    __hv_zero_f(VOf(Bf8));
    __hv_lt_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_and_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_cast_fi(VIf(Bf8), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_zmc7VCxE, VIi(Bi1), VOf(Bf8));
    __hv_tabread_if(&sTabread_SHtd5177, VIi(Bi0), VOf(Bf5));
    __hv_sub_f(VIf(Bf8), VIf(Bf5), VOf(Bf8));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf8), VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_nzhXFS5d, VOf(Bf9));
    __hv_mul_f(VIf(Bf5), VIf(Bf9), VOf(Bf8));
    __hv_fma_f(VIf(Bf0), VIf(Bf11), VIf(Bf8), VOf(Bf8));
    __hv_tabhead_f(&sTabhead_FVTADis8, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_yBhnDiMj, VOf(Bf3));
    __hv_mul_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_HZ1FVPwN, VOf(Bf10));
    __hv_min_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf12), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf12));
    __hv_varread_f(&sVarf_6KJEPjWl, VOf(Bf10));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_WbarWyuN, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_FjRoJ2ml, VIi(Bi0), VOf(Bf10));
    __hv_sub_f(VIf(Bf13), VIf(Bf10), VOf(Bf13));
    __hv_sub_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf9));
    __hv_fma_f(VIf(Bf11), VIf(Bf6), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_oL7M6Xm2, VOf(Bf11));
    __hv_fma_f(VIf(Bf11), VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_tabwrite_f(&sTabwrite_7S872WnF, VIf(Bf6));
    __hv_fma_f(VIf(Bf5), VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_BpMsIEFE, VIf(Bf0));
    __hv_varwrite_f(&sVarf_1oncvnX1, VIf(Bf8));
    __hv_line_f(&sLine_vTZQqP6D, VOf(Bf8));
    __hv_phasor_k_f(&sPhasor_xR2zUXJ0, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_abs_f(VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf11), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_du0DsJXK, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_neg_f(VIf(Bf0), VOf(Bf5));
    __hv_add_f(VIf(Bf5), VIf(Bf6), VOf(Bf5));
    __hv_varread_f(&sVarf_oxHaTdLu, VOf(Bf11));
    __hv_mul_f(VIf(Bf5), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_fctQKI10, VOf(Bf5));
    __hv_rpole_f(&sRPole_hbb4vwH1, VIf(Bf11), VIf(Bf5), VOf(Bf5));
    __hv_add_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_mi8KmQGX, VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_Yj8RlYNe, VOf(Bf6));
    __hv_rpole_f(&sRPole_0bHYdgYU, VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_tabhead_f(&sTabhead_Jwd0p7Mw, VOf(Bf0));
    __hv_var_k_f_r(VOf(Bf11), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_tvFyZ1ua, VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_bHHbWflu, VOf(Bf6));
    __hv_min_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_zero_f(VOf(Bf0));
    __hv_max_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_sub_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_floor_f(VIf(Bf0), VOf(Bf11));
    __hv_varread_f(&sVarf_Bi2SnjfS, VOf(Bf6));
    __hv_zero_f(VOf(Bf10));
    __hv_lt_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_and_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_cast_fi(VIf(Bf10), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_tmd7bIei, VIi(Bi1), VOf(Bf10));
    __hv_tabread_if(&sTabread_F6oku9W2, VIi(Bi0), VOf(Bf6));
    __hv_sub_f(VIf(Bf10), VIf(Bf6), VOf(Bf10));
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_fma_f(VIf(Bf10), VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_ywzdwClY, VOf(Bf11));
    __hv_mul_f(VIf(Bf6), VIf(Bf11), VOf(Bf10));
    __hv_fma_f(VIf(Bf4), VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_tabhead_f(&sTabhead_1PTo7N8K, VOf(Bf0));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf0), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_9L9OUyIT, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_Df7J1ILx, VOf(Bf5));
    __hv_min_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_zero_f(VOf(Bf0));
    __hv_max_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_sub_f(VIf(Bf12), VIf(Bf0), VOf(Bf0));
    __hv_floor_f(VIf(Bf0), VOf(Bf12));
    __hv_varread_f(&sVarf_rnD4csW9, VOf(Bf5));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf5), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_nMyeTIE1, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_dlHaok7b, VIi(Bi0), VOf(Bf5));
    __hv_sub_f(VIf(Bf13), VIf(Bf5), VOf(Bf13));
    __hv_sub_f(VIf(Bf0), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf11), VIf(Bf5), VOf(Bf11));
    __hv_fma_f(VIf(Bf8), VIf(Bf7), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_KVnkE6T3, VOf(Bf8));
    __hv_fma_f(VIf(Bf8), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_tabwrite_f(&sTabwrite_KDBXC4TL, VIf(Bf7));
    __hv_fma_f(VIf(Bf6), VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_tabwrite_f(&sTabwrite_dqPiu7M0, VIf(Bf4));
    __hv_varwrite_f(&sVarf_YYNItq1f, VIf(Bf10));
    __hv_varwrite_f(&sVarf_78x0NDZd, VIf(Bf2));
    __hv_varwrite_f(&sVarf_Cxcsl74I, VIf(Bf9));
    __hv_varwrite_f(&sVarf_ez2Up39d, VIf(Bf11));
    __hv_varread_f(&sVarf_otlHgdcg, VOf(Bf11));
    __hv_varread_f(&sVarf_1oncvnX1, VOf(Bf9));
    __hv_varread_f(&sVarf_YYNItq1f, VOf(Bf2));
    __hv_add_f(VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf11), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));
    __hv_varread_f(&sVarf_78x0NDZd, VOf(Bf2));
    __hv_varread_f(&sVarf_Cxcsl74I, VOf(Bf11));
    __hv_varread_f(&sVarf_ez2Up39d, VOf(Bf9));
    __hv_add_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf9), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_FL3NGR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_FL3NGR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
